@@ -33,7 +33,7 @@
 
 
 // We declare an auto pointer to BaaderDome.
-std::auto_ptr<BaaderDome> baaderDome(0);
+std::unique_ptr<BaaderDome> baaderDome(new BaaderDome());
 
 #define POLLMS              1000            /* Update frequency 1000 ms */
 #define DOME_AZ_THRESHOLD   1               /* Error threshold in degrees*/
@@ -48,57 +48,40 @@ std::auto_ptr<BaaderDome> baaderDome(0);
 
 void ISPoll(void *p);
 
-void ISInit()
-{
-   static int isInit =0;
-
-   if (isInit == 1)
-       return;
-
-    isInit = 1;
-    if(baaderDome.get() == 0) baaderDome.reset(new BaaderDome());
-
-}
-
 void ISGetProperties(const char *dev)
 {
-        ISInit();
-        baaderDome->ISGetProperties(dev);
+    baaderDome->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-        ISInit();
-        baaderDome->ISNewSwitch(dev, name, states, names, num);
+    baaderDome->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-        ISInit();
-        baaderDome->ISNewText(dev, name, texts, names, num);
+    baaderDome->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-        ISInit();
-        baaderDome->ISNewNumber(dev, name, values, names, num);
+    baaderDome->ISNewNumber(dev, name, values, names, num);
 }
 
 void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[], char *names[], int n)
 {
-  INDI_UNUSED(dev);
-  INDI_UNUSED(name);
-  INDI_UNUSED(sizes);
-  INDI_UNUSED(blobsizes);
-  INDI_UNUSED(blobs);
-  INDI_UNUSED(formats);
-  INDI_UNUSED(names);
-  INDI_UNUSED(n);
+    INDI_UNUSED(dev);
+    INDI_UNUSED(name);
+    INDI_UNUSED(sizes);
+    INDI_UNUSED(blobsizes);
+    INDI_UNUSED(blobs);
+    INDI_UNUSED(formats);
+    INDI_UNUSED(names);
+    INDI_UNUSED(n);
 }
 
 void ISSnoopDevice (XMLEle *root)
 {
-    ISInit();
     baaderDome->ISSnoopDevice(root);
 }
 
@@ -118,16 +101,7 @@ BaaderDome::BaaderDome()
    targetFlap       = FLAP_CLOSE;
    calibrationStage = CALIBRATION_UNKNOWN;
 
-   DomeCapability cap;
-
-   cap.canAbort = true;         // no real abort, we set target position to current position to "abort"
-   cap.canAbsMove = true;
-   cap.canRelMove = true;
-   cap.hasShutter = true;
-   cap.canPark    = true;
-   cap.hasVariableSpeed = false;
-
-   SetDomeCapability(&cap);
+   SetDomeCapability(DOME_CAN_ABORT | DOME_CAN_ABS_MOVE | DOME_CAN_REL_MOVE | DOME_CAN_PARK | DOME_HAS_SHUTTER | DOME_HAS_VARIABLE_SPEED);
 
 }
 
@@ -669,24 +643,19 @@ void BaaderDome::TimerHit()
                 DomeAbsPosN[0].value -= DomeAbsPosN[0].max;
         }
 
-        if (fabs(targetAz - DomeAbsPosN[0].value) < DomeParamN[DOME_AUTOSYNC].value)
+        if (fabs(targetAz - DomeAbsPosN[0].value) < DomeParamN[0].value)
         {
             DomeAbsPosN[0].value = targetAz;
-            DomeAbsPosNP.s = IPS_OK;
             DEBUG(INDI::Logger::DBG_SESSION, "Dome reached requested azimuth angle.");
 
-            if (domeState == DOME_PARKING && status != DOME_CALIBRATING)
-                SetParked(true);
-
-            if (DomeGotoSP.s == IPS_BUSY)
+            if (status != DOME_CALIBRATING)
             {
-                DomeGotoSP.s = IPS_OK;
-                IDSetSwitch(&DomeGotoSP, NULL);
-            }
-            if (DomeRelPosNP.s == IPS_BUSY)
-            {
-                DomeRelPosNP.s = IPS_OK;
-                IDSetNumber(&DomeRelPosNP, NULL);
+                if (getDomeState() == DOME_PARKING)
+                    SetParked(true);
+                else if (getDomeState() == DOME_UNPARKING)
+                    SetParked(false);
+                else
+                    setDomeState(DOME_SYNCED);
             }
 
             if (status == DOME_CALIBRATING)
@@ -840,16 +809,6 @@ IPState BaaderDome::UnPark()
 }
 
 
-/************************************************************************************
- *
-* ***********************************************************************************/
-IPState BaaderDome::Home()
-{
-    targetAz = DomeParamN[DOME_HOME].value;
-
-    return MoveAbs(targetAz);
-}
-
 /************************************************************************************
  *
 * ***********************************************************************************/
