@@ -29,46 +29,30 @@
 #include <indicom.h>
 
 // We declare an auto pointer to domeSim.
-std::auto_ptr<DomeSim> domeSim(0);
+std::unique_ptr<DomeSim> domeSim(new DomeSim());
 
 #define DOME_SPEED      2.0             /* 2 degrees per second, constant */
 #define SHUTTER_TIMER   5.0             /* Shutter closes/open in 5 seconds */
 
 void ISPoll(void *p);
 
-void ISInit()
-{
-   static int isInit =0;
-
-   if (isInit == 1)
-       return;
-
-    isInit = 1;
-    if(domeSim.get() == 0) domeSim.reset(new DomeSim());
-
-}
-
 void ISGetProperties(const char *dev)
 {
-        ISInit();
         domeSim->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-        ISInit();
         domeSim->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-        ISInit();
         domeSim->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-        ISInit();
         domeSim->ISNewNumber(dev, name, values, names, num);
 }
 
@@ -86,28 +70,18 @@ void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[],
 
 void ISSnoopDevice (XMLEle *root)
 {
-    ISInit();
     domeSim->ISSnoopDevice(root);
 }
 
 DomeSim::DomeSim()
 {
-
    targetAz = 0;
    shutterTimer=0;
    prev_az=0;
    prev_alt=0;
+   TimeSinceUpdate=0;
 
-   DomeCapability cap;
-
-   cap.canAbort = true;
-   cap.canAbsMove = true;
-   cap.canRelMove = true;
-   cap.hasShutter = true;
-   cap.canPark    = true;
-   cap.hasVariableSpeed = false;
-
-   SetDomeCapability(&cap);   
+   SetDomeCapability(DOME_CAN_ABORT | DOME_CAN_ABS_MOVE | DOME_CAN_REL_MOVE | DOME_CAN_PARK | DOME_HAS_SHUTTER);
 
 }
 
@@ -132,8 +106,7 @@ bool DomeSim::SetupParms()
 
     DomeAbsPosN[0].value = 0;
 
-    DomeParamN[DOME_HOME].value  = 90;
-    DomeParamN[DOME_AUTOSYNC].value  = 5;
+    DomeParamN[0].value  = 5;
 
     IDSetNumber(&DomeAbsPosNP, NULL);
     IDSetNumber(&DomeParamNP, NULL);
@@ -209,24 +182,14 @@ void DomeSim::TimerHit()
         if (fabs(targetAz - DomeAbsPosN[0].value) <= DOME_SPEED)
         {
             DomeAbsPosN[0].value = targetAz;
-            DomeAbsPosNP.s = IPS_OK;
             DEBUG(INDI::Logger::DBG_SESSION, "Dome reached requested azimuth angle.");
 
-            if (domeState == DOME_PARKING)
-            {
+            if (getDomeState() == DOME_PARKING)
                 SetParked(true);
-            }
-
-            if (DomeGotoSP.s == IPS_BUSY)
-            {
-                DomeGotoSP.s = IPS_OK;
-                IDSetSwitch(&DomeGotoSP, NULL);
-            }
-            if (GetDomeCapability().canRelMove && DomeRelPosNP.s == IPS_BUSY)
-            {
-                DomeRelPosNP.s = IPS_OK;
-                IDSetNumber(&DomeRelPosNP, NULL);
-            }
+            else if (getDomeState() == DOME_UNPARKING)
+                SetParked(false);
+            else
+                setDomeState(DOME_SYNCED);
         }
 
         IDSetNumber(&DomeAbsPosNP, NULL);
@@ -240,13 +203,25 @@ void DomeSim::TimerHit()
             DomeShutterSP.s = IPS_OK;
             DEBUGF(INDI::Logger::DBG_SESSION, "Shutter is %s.", (DomeShutterS[0].s == ISS_ON ? "open" : "closed"));
             IDSetSwitch(&DomeShutterSP, NULL);
+
+            if (getDomeState() == DOME_UNPARKING)
+                SetParked(false);
         }
     }
     SetTimer(nexttimer);
+    //  Not all mounts update ra/dec constantly if tracking co-ordinates
+    //  This is to ensure our alt/az gets updated even if ra/dec isn't being updated
+    //  Once every 10 seconds is more than sufficient
+    //  with this added, dome simulator will now correctly track telescope simulator
+    //  which does not emit new ra/dec co-ords if they are not changing
+    if(TimeSinceUpdate++ > 9) {
+	TimeSinceUpdate=0;
+	UpdateMountCoords();
+    }
     return;
 }
 
-bool DomeSim::Move(DomeDirection dir, DomeMotionCommand operation)
+IPState DomeSim::Move(DomeDirection dir, DomeMotionCommand operation)
 {
     if (operation == MOTION_START)
     {
@@ -260,17 +235,19 @@ bool DomeSim::Move(DomeDirection dir, DomeMotionCommand operation)
     }
 
     IDSetNumber(&DomeAbsPosNP, NULL);
-    return true;
+    return ( (operation == MOTION_START) ? IPS_BUSY : IPS_OK);
 
 }
 
 IPState DomeSim::MoveAbs(double az)
 {
+    targetAz = az;
+
     // Requested position is within one cycle, let's declare it done
     if (fabs(az - DomeAbsPosN[0].value) < DOME_SPEED)
         return IPS_OK;
 
-    targetAz = az;
+
 
     // It will take a few cycles to reach final position
     return IPS_BUSY;
@@ -298,24 +275,18 @@ IPState DomeSim::MoveRel(double azDiff)
 IPState DomeSim::Park()
 {
     targetAz = DomeParamN[1].value;
-    domeState = DOME_PARKING;
-    return MoveAbs(GetAxis1Park());
+    Dome::ControlShutter(SHUTTER_CLOSE);
+    Dome::MoveAbs(GetAxis1Park());
+
+    return IPS_BUSY;
 }
 
 IPState DomeSim::UnPark()
 {
-    domeState = DOME_IDLE;
-    return IPS_OK;
+    return Dome::ControlShutter(SHUTTER_OPEN);
 }
 
-IPState DomeSim::Home()
-{
-    targetAz = DomeParamN[0].value;
-    DomeAbsPosNP.s = IPS_BUSY;
-    return IPS_BUSY;
-}
-
-IPState DomeSim::ControlShutter(ShutterStatus operation)
+IPState DomeSim::ControlShutter(ShutterOperation operation)
 {
     INDI_UNUSED(operation);
     shutterTimer = SHUTTER_TIMER;
@@ -323,17 +294,7 @@ IPState DomeSim::ControlShutter(ShutterStatus operation)
 }
 
 bool DomeSim::Abort()
-{
-    DomeAbsPosNP.s = IPS_IDLE;
-    IDSetNumber(&DomeAbsPosNP, NULL);
-
-    if (DomeGotoSP.s == IPS_BUSY)
-    {
-        IUResetSwitch(&DomeGotoSP);
-        DomeGotoSP.s = IPS_IDLE;
-        IDSetSwitch(&DomeGotoSP, "Dome Goto aborted.");
-    }
-
+{    
     // If we abort while in the middle of opening/closing shutter, alert.
     if (DomeShutterSP.s == IPS_BUSY)
     {
