@@ -37,30 +37,31 @@ class DomeSim : public INDI::Dome
         const char *getDefaultName();
         bool updateProperties();
 
+protected:
         bool Connect();
         bool Disconnect();
 
         void TimerHit();
 
-        virtual bool Move(DomeDirection dir, DomeMotionCommand operation);
+        virtual IPState Move(DomeDirection dir, DomeMotionCommand operation);
         virtual IPState MoveRel(double azDiff);
         virtual IPState MoveAbs(double az);        
         virtual IPState Park();
         virtual IPState UnPark();
-        virtual IPState Home();
-        virtual IPState ControlShutter(ShutterStatus operation);
+        virtual IPState ControlShutter(ShutterOperation operation);
         virtual bool Abort();
 
         // Parking
         virtual void SetCurrentPark();
         virtual void SetDefaultPark();
 
-    protected:
+
     private:
 
         double targetAz;
         double shutterTimer;
         bool SetupParms();
+	int TimeSinceUpdate;
 
 };
 
