@@ -27,7 +27,7 @@
 
 
 // We declare an auto pointer to focusSim.
-std::auto_ptr<FocusSim> focusSim(0);
+std::unique_ptr<FocusSim> focusSim(new FocusSim());
 
 #define SIM_SEEING  0
 #define SIM_FWHM    1
@@ -35,40 +35,23 @@ std::auto_ptr<FocusSim> focusSim(0);
 
 void ISPoll(void *p);
 
-
-void ISInit()
-{
-   static int isInit =0;
-
-   if (isInit == 1)
-       return;
-
-    isInit = 1;
-    if(focusSim.get() == 0) focusSim.reset(new FocusSim());
-
-}
-
 void ISGetProperties(const char *dev)
 {
-        ISInit();
         focusSim->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-        ISInit();
         focusSim->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-        ISInit();
         focusSim->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-        ISInit();
         focusSim->ISNewNumber(dev, name, values, names, num);
 }
 
@@ -86,7 +69,6 @@ void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[],
 
 void ISSnoopDevice (XMLEle *root)
 {
-    ISInit();
     focusSim->ISSnoopDevice(root);
 }
 
@@ -94,14 +76,7 @@ FocusSim::FocusSim()
 {
     ticks=0;
 
-    FocuserCapability cap;
-    cap.canAbort=true;
-    cap.canAbsMove=true;
-    cap.canRelMove=true;
-    cap.variableSpeed=true;
-
-    SetFocuserCapability(&cap);
-
+    SetFocuserCapability(FOCUSER_CAN_ABS_MOVE | FOCUSER_CAN_REL_MOVE | FOCUSER_CAN_ABORT | FOCUSER_HAS_VARIABLE_SPEED);
 }
 
 bool FocusSim::SetupParms()
@@ -295,3 +270,7 @@ IPState FocusSim::MoveRelFocuser(FocusDirection dir, uint32_t ticks)
     return MoveAbsFocuser(targetTicks);
 }
 
+bool FocusSim::SetFocuserSpeed(int speed) {
+  return true;
+}
+
