@@ -33,40 +33,25 @@
 
 #define POLLMS  250
 
-std::auto_ptr<MoonLite> moonLite(0);
-
-void ISInit()
-{
-    static int isInit =0;
-
-    if (isInit == 1)
-        return;
-
-     isInit = 1;
-     if(moonLite.get() == 0) moonLite.reset(new MoonLite());
-}
+std::unique_ptr<MoonLite> moonLite(new MoonLite());
 
 void ISGetProperties(const char *dev)
 {
-         ISInit();
          moonLite->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-         ISInit();
          moonLite->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-         ISInit();
          moonLite->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-         ISInit();
          moonLite->ISNewNumber(dev, name, values, names, num);
 }
 
@@ -84,21 +69,14 @@ void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[],
 
 void ISSnoopDevice (XMLEle *root)
 {
-     ISInit();
      moonLite->ISSnoopDevice(root);
 }
 
 MoonLite::MoonLite()
 {
 
-    // Can move in Absolute & Relative motions, can AbortFocuser motion, and has variable speed.
-    FocuserCapability cap;
-    cap.canAbort=true;
-    cap.canAbsMove=true;
-    cap.canRelMove=true;
-    cap.variableSpeed=true;
-
-    SetFocuserCapability(&cap);
+    // Can move in Absolute & Relative motions, can AbortFocuser motion, and has variable speed.        
+    SetFocuserCapability(FOCUSER_CAN_ABS_MOVE | FOCUSER_CAN_REL_MOVE | FOCUSER_CAN_ABORT | FOCUSER_HAS_VARIABLE_SPEED);
 
     lastPos = 0;
     lastTemperature = 0;
@@ -161,13 +139,6 @@ bool MoonLite::initProperties()
 
 }
 
-void MoonLite::ISGetProperties(const char *dev)
-{
-    INDI::Focuser::ISGetProperties(dev);
-
-    defineText(&PortTP);
-}
-
 bool MoonLite::updateProperties()
 {
     INDI::Focuser::updateProperties();
