@@ -36,7 +36,6 @@ public:
     const char * getDefaultName();
     virtual bool initProperties();
     virtual bool updateProperties();
-    virtual void ISGetProperties(const char *dev);
     virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
     virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
     virtual IPState MoveFocuser(FocusDirection dir, int speed, uint16_t duration);
@@ -51,6 +50,7 @@ protected:
 private:
 
     int PortFD;
+    int timerID;
     double targetPos;
     double simulatedTemperature;
     double simulatedPosition;
@@ -66,13 +66,15 @@ private:
     int updateRFBacklash(double *value);
     int updateRFFirmware(char *rf_cmd) ;
     int updateRFMotorSettings(double *duty, double *delay, double *ticks);
-    int updateRFPositionRelativeInward(double *value);
-    int updateRFPositionRelativeOutward(double *value) ;
-    int updateRFPositionAbsolute(double *value);
+    int updateRFPositionRelativeInward(double value);
+    int updateRFPositionRelativeOutward(double value);
+    int updateRFPositionAbsolute(double value);
     int updateRFPowerSwitches(int s, int  new_sn, int *cur_s1LL, int *cur_s2LR, int *cur_s3RL, int *cur_s4RR) ;
     int updateRFMaxPosition(double *value);
     int updateRFSetPosition(double *value);
 
+    int ReadUntilComplete(char *buf, int timeout);
+
 
     INumber TemperatureN[1];
     INumberVectorProperty TemperatureNP;
