@@ -41,40 +41,25 @@
 
 #define POLLMS  500
 
-std::auto_ptr<SteelDrive> steelDrive(0);
-
-void ISInit()
-{
-    static int isInit =0;
-
-    if (isInit == 1)
-        return;
-
-     isInit = 1;
-     if(steelDrive.get() == 0) steelDrive.reset(new SteelDrive());
-}
+std::unique_ptr<SteelDrive> steelDrive(new SteelDrive());
 
 void ISGetProperties(const char *dev)
 {
-         ISInit();
          steelDrive->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-         ISInit();
          steelDrive->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-         ISInit();
          steelDrive->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-         ISInit();
          steelDrive->ISNewNumber(dev, name, values, names, num);
 }
 
@@ -92,21 +77,14 @@ void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[],
 
 void ISSnoopDevice (XMLEle *root)
 {
-     ISInit();
      steelDrive->ISSnoopDevice(root);
 }
 
 SteelDrive::SteelDrive()
 {
 
-    // Can move in Absolute & Relative motions, can AbortFocuser motion, and has variable speed.
-    FocuserCapability cap;
-    cap.canAbort=true;
-    cap.canAbsMove=true;
-    cap.canRelMove=true;
-    cap.variableSpeed=true;
-
-    SetFocuserCapability(&cap);
+    // Can move in Absolute & Relative motions, can AbortFocuser motion, and has variable speed.   
+    SetFocuserCapability(FOCUSER_CAN_ABS_MOVE | FOCUSER_CAN_REL_MOVE | FOCUSER_CAN_ABORT | FOCUSER_HAS_VARIABLE_SPEED);
 
     sim=false;
     lastPos = 0;
