@@ -18,6 +18,10 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
+/*
+    Version with experimental pulse guide support. GC 04.12.2015
+*/
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -142,6 +146,8 @@ bool check_celestron_connection(int fd)
       }
       else
       {
+          tcflush(fd, TCIOFLUSH);
+
           if ( (errcode = tty_write(fd, initCMD, 2, &nbytes_written)) != TTY_OK)
           {
               tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -232,6 +238,8 @@ bool get_celestron_version (int fd, FirmwareInfo *info)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -263,8 +271,6 @@ bool get_celestron_version (int fd, FirmwareInfo *info)
          info->controllerVersion = atof(versionStr);
          info->Version  = versionStr;
 
-         tcflush(fd, TCIFLUSH);
-
           return true;
       }
     }
@@ -293,6 +299,8 @@ bool get_celestron_model (int fd, FirmwareInfo *info)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -326,8 +334,6 @@ bool get_celestron_model (int fd, FirmwareInfo *info)
               info->Model = "Unknown";
           }
 
-          tcflush(fd, TCIFLUSH);
-
           return true;
       }
     }
@@ -357,6 +363,8 @@ bool get_celestron_ra_firmware(int fd, FirmwareInfo *info)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, (char *) cmd, 8, &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -387,8 +395,6 @@ bool get_celestron_ra_firmware(int fd, FirmwareInfo *info)
 
          info->RAFirmware  = versionStr;
 
-         tcflush(fd, TCIFLUSH);
-
          return true;
       }
 
@@ -418,6 +424,8 @@ bool get_celestron_dec_firmware(int fd, FirmwareInfo *info)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, (char *) cmd, 8, &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -448,8 +456,6 @@ bool get_celestron_dec_firmware(int fd, FirmwareInfo *info)
 
          info->DEFirmware = versionStr;
 
-         tcflush(fd, TCIFLUSH);
-
          return true;
       }
 
@@ -479,6 +485,8 @@ bool get_celestron_gps_firmware(int fd, FirmwareInfo *info)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, (char *) cmd, 8, &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -508,9 +516,6 @@ bool get_celestron_gps_firmware(int fd, FirmwareInfo *info)
           snprintf(versionStr, 8, "%01d.%01d", major, minor);
 
          info->GPSFirmware = versionStr;
-
-         tcflush(fd, TCIFLUSH);
-
          return true;
       }
 
@@ -520,6 +525,194 @@ bool get_celestron_gps_firmware(int fd, FirmwareInfo *info)
     return false;
 }
 
+
+/*****************************************************************
+ PulseGuide commands, experimental:                              *
+                                                                 *
+     SendPulseCmd( int fd,                                       *
+                   CELESTRON_DIRECTION direction,                *
+                   signed char rate,                             *
+                   unsigned char duration_csec );                *
+                                                                 *
+       Send a guiding pulse to the  mount connected to "fd",     *
+       in direction "direction". "rate" should be a * signed     *
+       8-bit integer in the range (-100,100) that represents     *
+       the pulse  velocity in % of sidereal. "duration_csec"     *
+       is an unsigned  8-bit integer (0,255) with  the pulse     *
+       duration in centiseconds (i.e. 1/100 s  =  10ms). The     *
+       max pulse duration is 2550 ms.                            *
+                                                                 *
+                                                                 *
+     SendPulseStatusCmd( int fd,                                 *
+                         CELESTRON_DIRECTION direction,          *
+                         bool & pulse_state );                   *
+                                                                 *
+       Send the guiding pulse status check command to device     *
+       "fd" for the motor responsible for "direction". If  a     *
+       pulse is being executed, "pulse_state" is  set  to 1,     *
+       whereas if the pulse motion has been  completed it is     *
+       set to 0. Return "false" if the status command fails,     *
+       otherwise return "true".                                  *
+******************************************************************/
+
+int SendPulseCmd(int fd, CELESTRON_DIRECTION direction, signed char rate, unsigned char duration_csec)
+{
+  
+  DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, " PULSE REQUEST: (FD:%02X, DIR:%02i, RATE:%02i, CSEC:%02i)", fd, direction, rate, duration_csec);
+  
+  char cmd[] = { 0x50, 0x04, 0x11, 0x26, 0x00, 0x00, 0x00, 0x00};
+  int errcode = 0;
+  char errmsg[MAXRBUF];
+  int nbytes_written=0, nbytes_read=0;
+  char response[8];  
+  
+  switch (direction)
+  {
+        case CELESTRON_N:
+            cmd[2] = 0x11;
+            cmd[4] = rate;
+            cmd[5] = duration_csec;
+            break;
+
+        case CELESTRON_S:
+            cmd[2] = 0x11;
+            cmd[4] = -rate;
+            cmd[5] = duration_csec;
+            break;
+
+        case CELESTRON_W:
+            cmd[2] = 0x10;
+            cmd[4] = rate;
+            cmd[5] = duration_csec;
+            break;
+
+        case CELESTRON_E:
+            cmd[2] = 0x10;
+            cmd[4] = -rate;
+            cmd[5] = duration_csec;
+            break;
+  }
+  
+  DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, "   COMMAND (%02X %02X %02X %02X %02X %02X %02X %02X)", cmd[0],cmd[1],cmd[2],cmd[3],(unsigned char)cmd[4],(unsigned char)cmd[5],cmd[6],cmd[7]);
+
+  if (celestron_simulation)
+   {
+       strcpy(response, "#");
+       nbytes_read = strlen(response);
+       DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, "    SIMULATION: NBYTES = %02i, RESPONSE = %s", nbytes_read, response);
+   }
+   else
+   {
+      tcflush(fd, TCIOFLUSH);
+
+       // Send command and check success.
+       DEBUGDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "   ISSUING COMMAND");
+       if ( (errcode = tty_write(fd, cmd, 8, &nbytes_written)) != TTY_OK)
+       {
+           tty_error_msg(errcode, errmsg, MAXRBUF);
+           DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+           return false;
+       }
+
+       DEBUGDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "   WAITING FOR REPLY");
+       // Receive response and check success.
+       if ( (errcode = tty_read(fd, response, 1, CELESTRON_TIMEOUT, &nbytes_read)))
+       {
+           tty_error_msg(errcode, errmsg, MAXRBUF);
+           DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+           return false;
+       }
+
+   }
+
+   if (nbytes_read == 1)
+   {
+     response[nbytes_read] = '\0';
+     DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, "    NBYTES = %i, RESPONSE = %02X", nbytes_read, response[0]);
+
+     return true;
+   }
+
+   DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "    RECEIVED %d BYTES, expected 1", nbytes_read);
+   return false;
+}
+
+
+int SendPulseStatusCmd(int fd, CELESTRON_DIRECTION direction, bool & pulse_state)
+{
+  
+  DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, " PULSE STATUS REQUEST: (FD:%02X, DIR:%02i)", fd, direction);
+  
+  char cmd[] = { 0x50, 0x03, 0x11, 0x27, 0x00, 0x00, 0x00, 0x01};
+  int errcode = 0;
+  char errmsg[MAXRBUF];
+  int nbytes_written=0, nbytes_read=0;
+  char response[8];  
+  
+  switch (direction)
+  {
+        case CELESTRON_N:
+        case CELESTRON_S:
+            cmd[2] = 0x11;
+            break;
+        case CELESTRON_W:
+        case CELESTRON_E:
+            cmd[2] = 0x10;
+            break;
+  }
+  
+  DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, "   COMMAND (%02X %02X %02X %02X %02X %02X %02X %02X)", cmd[0],cmd[1],cmd[2],cmd[3],cmd[4],cmd[5],cmd[6],cmd[7]);
+
+  if (celestron_simulation)
+   {
+       strcpy(response, "0#");
+       nbytes_read = strlen(response);
+       DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, "    SIMULATION: NBYTES = %02i, RESPONSE = %s", nbytes_read, response);
+   }
+   else
+   {
+      tcflush(fd, TCIOFLUSH);
+
+       DEBUGDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "   ISSUING COMMAND");
+       if ( (errcode = tty_write(fd, cmd, 8, &nbytes_written)) != TTY_OK)
+       {
+           tty_error_msg(errcode, errmsg, MAXRBUF);
+           DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+           return false;
+       }
+       DEBUGDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "   WAITING FOR REPLY");
+       if ( (errcode = tty_read_section(fd, response, '#', CELESTRON_TIMEOUT, &nbytes_read)))
+       {
+           tty_error_msg(errcode, errmsg, MAXRBUF);
+           DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+           return false;
+       }
+
+   }
+
+   if (nbytes_read == 2)
+   {
+     response[nbytes_read] = '\0';
+     DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, "    NBYTES = %i, RESPONSE = %02X %02X", nbytes_read, (unsigned char)response[0], (unsigned char)response[1]);
+     
+     if(response[0]==0 && response[1]=='#'){
+       pulse_state = 0;
+     }
+     else if(response[0]==1 && response[1]=='#'){
+       pulse_state = 1;
+     }
+     else{
+       DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_WARNING, "    UNEXPECTED RESPONSE: %02X %02X", (unsigned char)response[0], (unsigned char)response[1]);
+       return false;
+     }
+     
+     return true;
+   }
+
+   DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "    RECEIVED %d BYTES, expected 2", nbytes_read);
+   return false;
+}
+
 bool start_celestron_motion(int fd, CELESTRON_DIRECTION dir, CELESTRON_SLEW_RATE rate)
 {
     char cmd[] = { 0x50, 0x02, 0x11, 0x24, 0x09, 0x00, 0x00, 0x00};
@@ -533,25 +726,25 @@ bool start_celestron_motion(int fd, CELESTRON_DIRECTION dir, CELESTRON_SLEW_RATE
         case CELESTRON_N:
             cmd[2] = 0x11;
             cmd[3] = 0x24;
-            cmd[4] = rate;
+            cmd[4] = rate+1;
             break;
 
         case CELESTRON_S:
             cmd[2] = 0x11;
             cmd[3] = 0x25;
-            cmd[4] = rate;
+            cmd[4] = rate+1;
             break;
 
         case CELESTRON_W:
             cmd[2] = 0x10;
             cmd[3] = 0x24;
-            cmd[4] = rate;
+            cmd[4] = rate+1;
             break;
 
         case CELESTRON_E:
             cmd[2] = 0x10;
             cmd[3] = 0x25;
-            cmd[4] = rate;
+            cmd[4] = rate+1;
             break;
     }
 
@@ -564,6 +757,8 @@ bool start_celestron_motion(int fd, CELESTRON_DIRECTION dir, CELESTRON_SLEW_RATE
    }
    else
    {
+       tcflush(fd, TCIOFLUSH);
+
        if ( (errcode = tty_write(fd, cmd, 8, &nbytes_written)) != TTY_OK)
        {
            tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -585,7 +780,6 @@ bool start_celestron_motion(int fd, CELESTRON_DIRECTION dir, CELESTRON_SLEW_RATE
      response[nbytes_read] = '\0';
      DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%s)", response);
 
-     tcflush(fd, TCIFLUSH);
      return true;
    }
 
@@ -626,6 +820,8 @@ bool stop_celestron_motion(int fd, CELESTRON_DIRECTION dir)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, 8, &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -645,8 +841,6 @@ bool stop_celestron_motion(int fd, CELESTRON_DIRECTION dir)
     {
       response[nbytes_read] = '\0';
       DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%s)", response);
-
-      tcflush(fd, TCIFLUSH);
       return true;
     }
 
@@ -672,6 +866,8 @@ bool abort_celestron(int fd)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -691,8 +887,6 @@ bool abort_celestron(int fd)
     {
       response[nbytes_read] = '\0';
       DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%s)", response);
-
-      tcflush(fd, TCIFLUSH);
       return true;
     }
 
@@ -732,6 +926,8 @@ bool slew_celestron(int fd, double ra, double dec)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -754,13 +950,11 @@ bool slew_celestron(int fd, double ra, double dec)
 
       if (!strcmp(response, "#"))
       {
-          tcflush(fd, TCIFLUSH);
           return true;
       }
       else
       {
           DEBUGDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "Requested object is below horizon.");
-          tcflush(fd, TCIFLUSH);
           return false;
       }
 
@@ -770,7 +964,7 @@ bool slew_celestron(int fd, double ra, double dec)
     return false;
 }
 
-bool slew_celestron_azalt(int fd, double az, double alt)
+bool slew_celestron_azalt(int fd, double latitude, double az, double alt)
 {
     char cmd[16];
     int errcode = 0;
@@ -779,10 +973,10 @@ bool slew_celestron_azalt(int fd, double az, double alt)
     int nbytes_read=0;
     int nbytes_written=0;
 
-    int az_int, alt_int;
+    uint16_t az_int, alt_int;
 
-    az_int  = get_angle_fraction(az);
-    alt_int = get_angle_fraction(alt);
+    az_int  = get_az_fraction(az);
+    alt_int = get_alt_fraction(latitude, alt, az);
 
     char AzStr[16], AltStr[16];
     fs_sexa(AzStr, az, 3, 3600);
@@ -802,6 +996,8 @@ bool slew_celestron_azalt(int fd, double az, double alt)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -824,13 +1020,11 @@ bool slew_celestron_azalt(int fd, double az, double alt)
 
       if (!strcmp(response, "#"))
       {
-          tcflush(fd, TCIFLUSH);
           return true;
       }
       else
       {
           DEBUGDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "Requested object is below horizon.");
-          tcflush(fd, TCIFLUSH);
           return false;
       }
 
@@ -872,6 +1066,8 @@ bool sync_celestron(int fd, double ra, double dec)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -894,13 +1090,11 @@ bool sync_celestron(int fd, double ra, double dec)
 
       if (!strcmp(response, "#"))
       {
-          tcflush(fd, TCIFLUSH);
           return true;
       }
       else
       {
           DEBUGDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "Requested object is below horizon.");
-          tcflush(fd, TCIFLUSH);
           return false;
       }
 
@@ -930,6 +1124,8 @@ bool get_celestron_coords(int fd, double *ra, double *dec)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -947,7 +1143,6 @@ bool get_celestron_coords(int fd, double *ra, double *dec)
 
     if (nbytes_read > 0)
     {
-      tcflush(fd, TCIFLUSH);
       response[nbytes_read] = '\0';      
 
       char ra_str[16], de_str[16];
@@ -987,7 +1182,7 @@ bool get_celestron_coords(int fd, double *ra, double *dec)
     return false;
 }
 
-bool get_celestron_coords_azalt(int fd, double *az, double *alt)
+bool get_celestron_coords_azalt(int fd, double latitude, double *az, double *alt)
 {
     char cmd[] = "Z";
     int errcode = 0;
@@ -1000,13 +1195,15 @@ bool get_celestron_coords_azalt(int fd, double *az, double *alt)
 
     if (celestron_simulation)
     {
-        int az_int = get_angle_fraction(simData.az);
-        int alt_int = get_angle_fraction(simData.alt);
+        int az_int = get_az_fraction(simData.az);
+        int alt_int = get_alt_fraction(latitude, simData.alt, simData.az);
         snprintf(response, 16, "%04X,%04X#", az_int, alt_int);
         nbytes_read = strlen(response);
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -1024,23 +1221,22 @@ bool get_celestron_coords_azalt(int fd, double *az, double *alt)
 
     if (nbytes_read > 0)
     {
-      tcflush(fd, TCIFLUSH);
-      response[nbytes_read] = '\0';
+      response[nbytes_read] = '\0';      
 
-      char az_str[16], alt_str[16];
-      memset(az_str, 0, 16);
-      memset(alt_str, 0, 16);
+      uint16_t CELESTRONAZ=0, CELESTRONALT=0;
 
-      strncpy(az_str, response, 4);
-      strncpy(alt_str, response+5, 4);
+      sscanf(response, "%hx,%hx#", &CELESTRONAZ, &CELESTRONALT);
 
-      int CELESTRONAZ  = strtol(az_str, NULL, 16);
-      int CELESTRONALT = strtol(alt_str, NULL, 16);     
+      *az  = ( (CELESTRONAZ -  0x4000) / 65536.0) * 360.0;
+      *alt = ( (CELESTRONALT - 0x4000) / 65536.0) * 360.0 + latitude;
 
-      *az  = (CELESTRONAZ / 65536.0) * 360.0;
-      *alt = (CELESTRONALT / 65536.0) * 360.0;
+      *az = range360(*az);
 
-      if (*alt > 90)
+      if (*alt > 90 && *alt <= 270)
+          *alt = 180 - *alt;
+      //else if (*alt > 180 && *alt < 270)
+        //  *alt = 180 - *alt;
+      else if (*alt > 270)
           *alt -= 360;
 
       char AzStr[16], AltStr[16];
@@ -1093,6 +1289,8 @@ bool set_celestron_location(int fd, double longitude, double latitude)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, 9, &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -1113,7 +1311,6 @@ bool set_celestron_location(int fd, double longitude, double latitude)
       response[nbytes_read] = '\0';
       DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%s)", response);
 
-      tcflush(fd, TCIFLUSH);
       return true;
     }
 
@@ -1145,9 +1342,9 @@ bool set_celestron_datetime(int fd, struct ln_date *utc, double utc_offset)
     cmd[6] = local_date.years - 2000;
 
     if (utc_offset < 0)
-        cmd[7] = 256 - ((unsigned int) fabs(utc_offset));
+        cmd[7] = 256 - ((uint16_t) fabs(utc_offset));
     else
-        cmd[7] = ((unsigned int) fabs(utc_offset));
+        cmd[7] = ((uint16_t) fabs(utc_offset));
 
     // Always assume standard time
     cmd[8] = 0;
@@ -1161,6 +1358,8 @@ bool set_celestron_datetime(int fd, struct ln_date *utc, double utc_offset)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, 9, &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -1181,7 +1380,6 @@ bool set_celestron_datetime(int fd, struct ln_date *utc, double utc_offset)
       response[nbytes_read] = '\0';
       DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%s)", response);
 
-      tcflush(fd, TCIFLUSH);
       return true;
     }
 
@@ -1216,6 +1414,8 @@ bool get_celestron_utc_date_time(int fd, double *utc_hours, int *yy, int *mm, in
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -1233,7 +1433,6 @@ bool get_celestron_utc_date_time(int fd, double *utc_hours, int *yy, int *mm, in
 
     if (nbytes_read > 0)
     {
-      tcflush(fd, TCIFLUSH);
       response[nbytes_read] = '\0';
       unsigned char *res = (unsigned char *) response;
       DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%02X %02X %02X %02X %02X %02X %02X %02X)", res[0],res[1],res[2],res[3],res[4],res[5],res[6],res[7]);
@@ -1300,6 +1499,8 @@ bool is_scope_slewing(int fd)
     }
     else
     {
+        tcflush(fd, TCIOFLUSH);
+
         if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
         {
             tty_error_msg(errcode, errmsg, MAXRBUF);
@@ -1333,29 +1534,246 @@ bool is_scope_slewing(int fd)
     return false;
 }
 
-unsigned int get_angle_fraction(double angle)
+bool get_celestron_track_mode(int fd, CELESTRON_TRACK_MODE *mode)
+{
+    char cmd[] = "t";
+    int errcode = 0;
+    char errmsg[MAXRBUF];
+    char response[8];
+    int nbytes_read=0;
+    int nbytes_written=0;
+
+    DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "CMD (%s)", cmd);
+
+    if (celestron_simulation)
+    {
+        response[0] = 2;
+        response[1] = '#';
+        nbytes_read = 2;
+    }
+    else
+    {
+        tcflush(fd, TCIOFLUSH);
+
+        if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
+        {
+            tty_error_msg(errcode, errmsg, MAXRBUF);
+            DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+            return false;
+        }
+
+        if ( (errcode = tty_read(fd, response, 2, CELESTRON_TIMEOUT, &nbytes_read)))
+        {
+            tty_error_msg(errcode, errmsg, MAXRBUF);
+            DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+            return false;
+        }
+    }
+
+    if (nbytes_read > 0)
+    {
+      response[nbytes_read] = '\0';
+      DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%02X %02X)", response[0], response[1]);
+
+      tcflush(fd, TCIFLUSH);
+
+      *mode = ((CELESTRON_TRACK_MODE) response[0]);
+
+      return true;
+    }
+
+    DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "Received #%d bytes, expected 1.", nbytes_read);
+    return false;
+
+}
+
+bool set_celestron_track_mode(int fd, CELESTRON_TRACK_MODE mode)
+{
+    char cmd[2];
+    int errcode = 0;
+    char errmsg[MAXRBUF];
+    char response[8];
+    int nbytes_read=0;
+    int nbytes_written=0;
+
+    cmd[0] = 'T';
+    cmd[1] = mode;
+
+    DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "CMD (%s)", cmd);
+
+    if (celestron_simulation)
+    {
+        strcpy(response, "#");
+        nbytes_read = strlen(response);
+    }
+    else
+    {
+        tcflush(fd, TCIOFLUSH);
+
+        if ( (errcode = tty_write(fd, cmd, 2, &nbytes_written)) != TTY_OK)
+        {
+            tty_error_msg(errcode, errmsg, MAXRBUF);
+            DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+            return false;
+        }
+
+        if ( (errcode = tty_read(fd, response, 1, CELESTRON_TIMEOUT, &nbytes_read)))
+        {
+            tty_error_msg(errcode, errmsg, MAXRBUF);
+            DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+            return false;
+        }
+    }
+
+    if (nbytes_read > 0)
+    {
+      response[nbytes_read] = '\0';
+      DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%s)", response);
+
+      if (!strcmp(response, "#"))
+      {
+          tcflush(fd, TCIFLUSH);
+          return true;
+      }
+      else
+      {
+          DEBUGDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "Error setting tracking mode.");
+          tcflush(fd, TCIFLUSH);
+          return false;
+      }
+    }
+
+    DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "Received #%d bytes, expected 1.", nbytes_read);
+    return false;
+}
+
+bool hibernate (int fd)
+{
+    char cmd[] = "x#";
+    int errcode = 0;
+    char errmsg[MAXRBUF];
+    int nbytes_written=0;
+
+    DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "CMD (%s)", cmd);
+
+    if (celestron_simulation)
+        return true;
+
+    tcflush(fd, TCIOFLUSH);
+
+    if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
+    {
+         tty_error_msg(errcode, errmsg, MAXRBUF);
+         DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+        return false;
+    }
+
+    return true;
+}
+
+bool wakeup (int fd)
+{
+    char cmd[] = "y#";
+    int errcode = 0;
+    char errmsg[MAXRBUF];
+    int nbytes_written=0;
+    int nbytes_read=0;
+    char response[1];
+
+    DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "CMD (%s)", cmd);
+
+    if (celestron_simulation)
+        return true;
+
+    tcflush(fd, TCIOFLUSH);
+
+    if ( (errcode = tty_write(fd, cmd, strlen(cmd), &nbytes_written)) != TTY_OK)
+    {
+         tty_error_msg(errcode, errmsg, MAXRBUF);
+         DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+        return false;
+    }
+
+    if ( (errcode = tty_read(fd, response, 1, CELESTRON_TIMEOUT, &nbytes_read)))
+    {
+        tty_error_msg(errcode, errmsg, MAXRBUF);
+        DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "%s", errmsg);
+        return false;
+    }
+
+    if (nbytes_read > 0)
+    {
+      response[nbytes_read] = '\0';
+      DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_DEBUG, "RES (%s)", response);
+
+      if (!strcmp(response, "#"))
+      {
+          tcflush(fd, TCIFLUSH);
+          return true;
+      }
+      else
+      {
+          DEBUGDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "Error waking up the mount.");
+          tcflush(fd, TCIFLUSH);
+          return false;
+      }
+    }
+
+    DEBUGFDEVICE(celestron_device, INDI::Logger::DBG_ERROR, "Received #%d bytes, expected 1.", nbytes_read);
+    return false;
+}
+
+uint16_t get_angle_fraction(double angle)
 {
     if (angle >= 0)
-        return ((unsigned int) (angle * 65536 / 360.0));
+        return ((uint16_t) (angle * 65536 / 360.0));
     else
-        return ((unsigned int) ((angle+360) * 65536 / 360.0));
+        return ((uint16_t) ((angle+360) * 65536 / 360.0));
 }
 
-unsigned int get_ra_fraction(double ra)
+uint16_t get_ra_fraction(double ra)
 {
-    return ((unsigned int) (ra * 15.0 * 65536 / 360.0));
+    return ((uint16_t) (ra * 15.0 * 65536 / 360.0));
 }
 
-unsigned int get_de_fraction(double de)
+uint16_t get_de_fraction(double de)
 {
-    unsigned int de_int=0;
+    uint16_t de_int=0;
 
     if (de >= 0)
-        de_int = (unsigned int) (de * 65536 / 360.0);
+        de_int = (uint16_t) (de * 65536 / 360.0);
     else
-        de_int = (unsigned int) ((de+360.0) * 65536 / 360.0);
+        de_int = (uint16_t) ((de+360.0) * 65536 / 360.0);
 
     return de_int;
 }
 
+uint16_t get_az_fraction(double az)
+{
+    return (uint16_t) (az * 65536 / 360.0) + 0x4000;
+}
+
+uint16_t get_alt_fraction(double lat, double alt, double az)
+{
+    uint16_t alt_int=0;
+
+    if (alt >= 0)
+    {
+        // North
+        if (az >= 270 || az <=90)
+            alt_int = (uint16_t) ((alt-lat) * 65536 / 360.0) + 0x4000;
+        else
+            alt_int = (uint16_t) ( (180 - (lat + alt)) * 65536 / 360.0) + 0x4000;
+    }
+    else
+    {
+        if (az >= 270 || az <=90)
+            alt_int = (uint16_t) ((360 - lat + alt) * 65536 / 360.0) + 0x4000;
+        else
+            alt_int = (uint16_t) ( (180 - (lat + alt)) * 65536 / 360.0) + 0x4000;
+    }
+
+    return alt_int;
+}
+
 
