@@ -18,6 +18,10 @@
 
 */
 
+/*
+    Version with experimental pulse guide support. GC 04.12.2015
+*/
+
 #ifndef CELESTRONGPS_H
 #define CELESTRONGPS_H
 
@@ -30,7 +34,11 @@
 
 #define	POLLMS		1000		/* poll period, ms */
 
-class CelestronGPS : public INDI::Telescope
+//GUIDE: guider header
+#include "indiguiderinterface.h"
+
+//GUIDE: guider parent
+class CelestronGPS : public INDI::Telescope, public INDI::GuiderInterface
 {
  public:
  CelestronGPS();
@@ -38,19 +46,23 @@ class CelestronGPS : public INDI::Telescope
 
  virtual const char *getDefaultName();
  virtual bool Connect();
- virtual bool Connect(const char * port, uint16_t baud);
+ virtual bool Connect(const char * port, uint32_t baud);
  virtual bool Disconnect();
  virtual bool ReadScopeStatus();
  virtual void ISGetProperties(const char *dev);
  virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
+ virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
  virtual bool initProperties();
  virtual bool updateProperties();
 
+ //GUIDE guideTimeout() funcion
+ void guideTimeout(CELESTRON_DIRECTION calldir);
+ 
 protected:
 
  // Goto, Sync, and Motion
  bool Goto(double ra,double dec);
- bool GotoAzAlt(double az, double alt);
+ //bool GotoAzAlt(double az, double alt);
  bool Sync(double ra, double dec);
  virtual bool MoveNS(INDI_DIR_NS dir, TelescopeMotionCommand command);
  virtual bool MoveWE(INDI_DIR_WE dir, TelescopeMotionCommand command);
@@ -60,24 +72,56 @@ protected:
  virtual bool updateLocation(double latitude, double longitude, double elevation);
  virtual bool updateTime(ln_date *utc, double utc_offset);
 
+ //GUIDE: guiding functions
+ virtual IPState GuideNorth(float ms);
+ virtual IPState GuideSouth(float ms);
+ virtual IPState GuideEast(float ms);
+ virtual IPState GuideWest(float ms);
+
+ //GUIDE guideTimeoutHelper() function
+ static void guideTimeoutHelperN(void *p);
+ static void guideTimeoutHelperS(void *p);
+ static void guideTimeoutHelperW(void *p);
+ static void guideTimeoutHelperE(void *p);
+ 
  // Parking
  virtual bool Park();
  virtual bool UnPark();
  virtual void SetCurrentPark();
  virtual void SetDefaultPark();
 
+ virtual bool saveConfigItems(FILE *fp);
+
  virtual void simulationTriggered(bool enable);
 
  void mountSim();
 
+ //GUIDE variables.
+ int    GuideNSTID;
+ int    GuideWETID;
+ CELESTRON_DIRECTION guide_direction;
+ 
  /* Firmware */
  IText   FirmwareT[5];
  ITextVectorProperty FirmwareTP;
 
- INumberVectorProperty HorizontalCoordsNP;
- INumber HorizontalCoordsN[2];
+ //INumberVectorProperty HorizontalCoordsNP;
+ //INumber HorizontalCoordsN[2];
 
+ ISwitch TrackS[4];
+ ISwitchVectorProperty TrackSP;
+
+ //GUIDE Pulse guide switch
+ ISwitchVectorProperty UsePulseCmdSP;
+ ISwitch UsePulseCmdS[2];
+
+ ISwitchVectorProperty UseHibernateSP;
+ ISwitch UseHibernateS[2];
+ 
 private:  
+
+ bool setTrackMode(CELESTRON_TRACK_MODE mode);
+
   int PortFD;
   double currentRA, currentDEC, currentAZ, currentALT;
   double targetRA, targetDEC, targetAZ, targetALT;
