@@ -35,40 +35,25 @@
 #define MOUNTINFO_TAB   "Mount Info"
 
 // We declare an auto pointer to IEQPro.
-std::auto_ptr<IEQPro> scope(0);
-
-void ISInit()
-{
-   static int isInit =0;
-
-   if (isInit == 1)
-       return;
-
-    isInit = 1;
-    if(scope.get() == 0) scope.reset(new IEQPro());
-}
+std::unique_ptr<IEQPro> scope(new IEQPro());
 
 void ISGetProperties(const char *dev)
 {
-        ISInit();
         scope->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-        ISInit();
         scope->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-        ISInit();
         scope->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-        ISInit();
         scope->ISNewNumber(dev, name, values, names, num);
 }
 
@@ -108,16 +93,7 @@ IEQPro::IEQPro()
 
     DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");
 
-    TelescopeCapability cap;
-
-    cap.canPark = true;
-    cap.canSync = true;
-    cap.canAbort = true;
-    cap.hasLocation = true;
-    cap.hasTime  = true;
-    cap.nSlewRate= 9;
-
-    SetTelescopeCapability(&cap);
+    SetTelescopeCapability(TELESCOPE_CAN_PARK | TELESCOPE_CAN_SYNC | TELESCOPE_CAN_ABORT | TELESCOPE_HAS_TIME | TELESCOPE_HAS_LOCATION,9);
 }
 
 IEQPro::~IEQPro()
@@ -183,7 +159,7 @@ bool IEQPro::initProperties()
 
     initGuiderProperties(getDeviceName(), MOTION_TAB);
 
-    setInterfaceDescriptor(getInterfaceDescriptor() | GUIDER_INTERFACE);
+    setDriverInterface(getDriverInterface() | GUIDER_INTERFACE);
 
     SetParkDataType(PARK_RA_DEC);
 
@@ -658,7 +634,7 @@ bool IEQPro::UnPark()
         return false;
 }
 
-bool IEQPro::Connect(const char *port, uint16_t baud)
+bool IEQPro::Connect(const char *port, uint32_t baud)
 {
     set_ieqpro_device(getDeviceName());
     sim = isSimulation();
