@@ -39,8 +39,7 @@
 LX200AstroPhysics::LX200AstroPhysics() : LX200Generic()
 {
     timeUpdated = locationUpdated = false;
-
-    DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");
+    initStatus= MOUNTNOTINITIALIZED;
 
     //ctor
     currentRA=get_local_sideral_time(0);
@@ -113,7 +112,7 @@ void LX200AstroPhysics::ISGetProperties(const char *dev)
         defineSwitch(&StartUpSP);
         defineText(&VersionInfo);
 
-        defineText(&DeclinationAxisTP);
+        //defineText(&DeclinationAxisTP);
 
         /* Motion group */
         defineSwitch (&TrackModeSP);
@@ -136,7 +135,7 @@ bool LX200AstroPhysics::updateProperties()
         defineSwitch(&StartUpSP);
         defineText(&VersionInfo);
 
-        defineText(&DeclinationAxisTP);
+        //defineText(&DeclinationAxisTP);
 
         /* Motion group */        
         defineSwitch (&TrackModeSP);
@@ -151,7 +150,7 @@ bool LX200AstroPhysics::updateProperties()
     {
         deleteProperty(StartUpSP.name);
         deleteProperty(VersionInfo.name);
-        deleteProperty(DeclinationAxisTP.name);
+        //deleteProperty(DeclinationAxisTP.name);
         deleteProperty(TrackModeSP.name);
         deleteProperty(SlewSpeedSP.name);
         deleteProperty(SwapSP.name);
@@ -176,11 +175,10 @@ bool LX200AstroPhysics::ISNewSwitch (const char *dev, const char *name, ISState
     if (!strcmp (name, StartUpSP.name))
     {
 	int switch_nr ;
-	static int mount_status= MOUNTNOTINITIALIZED ;
 
 	IUUpdateSwitch(&StartUpSP, states, names, n) ;
 
-    if ( mount_status == MOUNTNOTINITIALIZED)
+    if ( initStatus == MOUNTNOTINITIALIZED)
 	{
         if (timeUpdated == false || locationUpdated == false)
         {
@@ -201,7 +199,7 @@ bool LX200AstroPhysics::ISNewSwitch (const char *dev, const char *name, ISState
             }
         }
 
-        mount_status=MOUNTINITIALIZED;
+        initStatus=MOUNTINITIALIZED;
 
 	    // Make sure that the mount is setup according to the properties	    
         switch_nr =  IUFindOnSwitchIndex(&TrackModeSP);
@@ -400,7 +398,6 @@ bool LX200AstroPhysics::ISNewNumber (const char *dev, const char *name, double v
     return LX200Generic::ISNewNumber(dev, name, values, names, n);
 }
 
-
 bool LX200AstroPhysics::isMountInit(void)
 {
     return (StartUpSP.s != IPS_IDLE);
@@ -424,7 +421,7 @@ bool LX200AstroPhysics::ReadScopeStatus()
        return false;
      }
 
-     if (TrackState == SCOPE_SLEWING || TrackState == SCOPE_PARKING)
+     if (TrackState == SCOPE_SLEWING)
      {
          double dx = targetRA - currentRA;
          double dy = targetDEC - currentDEC;
@@ -432,25 +429,36 @@ bool LX200AstroPhysics::ReadScopeStatus()
          // Wait until acknowledged or within threshold
          if ( fabs(dx) <= (SlewAccuracyN[0].value/(900.0)) && fabs(dy) <= (SlewAccuracyN[1].value/60.0))
          {
-             if (TrackState == SCOPE_SLEWING)
-             {
-                 TrackState=SCOPE_TRACKING;
-                 DEBUG(INDI::Logger::DBG_SESSION, "Slew is complete. Tracking...");
-             }
-             else
-             {
-                 DEBUG(INDI::Logger::DBG_DEBUG, "Parking slew is complete. Asking astrophysics mount to park...");
-                 if (isSimulation() == false)
-                 {
-                     if (setAPPark(PortFD) < 0)
-                     {
-                       DEBUG(INDI::Logger::DBG_ERROR, "Parking Failed.");
-                       return false;
-                     }
-                 }
+             TrackState=SCOPE_TRACKING;
+             DEBUG(INDI::Logger::DBG_SESSION, "Slew is complete. Tracking...");
+         }
+     }
+     else if (TrackState == SCOPE_PARKING)
+     {
+         double currentAlt, currentAz;
+         if ( getLX200Az(PortFD, &currentAz) < 0 || getLX200Alt(PortFD, &currentAlt) < 0)
+         {
+           EqNP.s = IPS_ALERT;
+           IDSetNumber(&EqNP, "Error reading Az/Alt.");
+           return false;
+         }
 
-                SetParked(true);
+         double dx = GetAxis1Park() - currentAz;
+         double dy = GetAxis2Park() - currentAlt;
+
+         DEBUGF(INDI::Logger::DBG_DEBUG, "Parking... targetAz: %g currentAz: %g dx: %g targetAlt: %g currentAlt: %g dy: %g", GetAxis1Park(),  currentAz, dx, GetAxis2Park(), currentAlt, dy);
+
+         if ( fabs(dx) <= (SlewAccuracyN[0].value/(60.0)) && fabs(dy) <= (SlewAccuracyN[1].value/60.0))
+         {
+             DEBUG(INDI::Logger::DBG_DEBUG, "Parking slew is complete. Asking astrophysics mount to park...");
+
+             if (isSimulation() == false && setAPPark(PortFD) < 0)
+             {
+                 DEBUG(INDI::Logger::DBG_ERROR, "Parking Failed.");
+                 return false;
              }
+
+             SetParked(true);
          }
      }
 
@@ -485,8 +493,12 @@ bool LX200AstroPhysics::setBasicDataPart0()
     
     if( (err = setAPBackLashCompensation(PortFD, 0,0,0)) < 0)
     {
-        DEBUGF(INDI::Logger::DBG_ERROR, "Error setting back lash compensation (%d): %s.", err, strerror(err));
-        return false;
+        // It seems we need to send it twice before it works!
+        if( (err = setAPBackLashCompensation(PortFD, 0,0,0)) < 0)
+        {
+            DEBUGF(INDI::Logger::DBG_ERROR, "Error setting back lash compensation (%d): %s.", err, strerror(err));
+            return false;
+        }
     }
 
     return true;
@@ -499,15 +511,16 @@ bool LX200AstroPhysics::setBasicDataPart1()
     if (InitPark())
     {
         // If loading parking data is successful, we just set the default parking values.
-        SetAxis1ParkDefault(0);
+        SetAxis1ParkDefault(LocationN[LOCATION_LATITUDE].value >= 0 ? 0 : 180);
         SetAxis2ParkDefault(LocationN[LOCATION_LATITUDE].value);
     }
     else
     {
         // Otherwise, we set all parking data to default in case no parking data is found.
-        SetAxis1Park(0);
-        SetAxis2Park(LocationN[LOCATION_LATITUDE].value);
-        SetAxis1ParkDefault(0);
+        SetAxis1Park(LocationN[LOCATION_LATITUDE].value >= 0 ? 0 : 180);
+        SetAxis1ParkDefault(LocationN[LOCATION_LATITUDE].value);
+
+        SetAxis1ParkDefault(LocationN[LOCATION_LATITUDE].value >= 0 ? 0 : 180);
         SetAxis2ParkDefault(LocationN[LOCATION_LATITUDE].value);
     }
 
@@ -589,7 +602,7 @@ bool LX200AstroPhysics::Goto(double r,double d)
     return true;
 }
 
-bool LX200AstroPhysics::Connect(const char *port, uint16_t baud)
+bool LX200AstroPhysics::Connect(const char *port, uint32_t baud)
 {
     if (isSimulation())
     {
@@ -753,7 +766,7 @@ bool LX200AstroPhysics::updateLocation(double latitude, double longitude, double
 void LX200AstroPhysics::debugTriggered(bool enable)
 {
    INDI_UNUSED(enable);
-   setLX200Debug(getDeviceName(), DBG_SCOPE);
+   LX200Generic::debugTriggered(enable);
    set_lx200ap_name(getDeviceName(), DBG_SCOPE);
 }
 
@@ -777,47 +790,40 @@ bool LX200AstroPhysics::SetSlewRate(int index)
 
 bool LX200AstroPhysics::Park()
 {
-    double parkAZ  = GetAxis1Park();
+    if (initStatus = MOUNTNOTINITIALIZED)
+    {
+        DEBUG(INDI::Logger::DBG_WARNING, "You must initialize the mount before parking.");
+        return false;
+    }
+
+    double parkAz  = GetAxis1Park();
     double parkAlt = GetAxis2Park();
 
     char AzStr[16], AltStr[16];
-    fs_sexa(AzStr, parkAZ, 2, 3600);
+    fs_sexa(AzStr, parkAz, 2, 3600);
     fs_sexa(AltStr, parkAlt, 2, 3600);
     DEBUGF(INDI::Logger::DBG_DEBUG, "Parking to Az (%s) Alt (%s)...", AzStr, AltStr);
 
-    ln_hrz_posn horizontalPos;
-    // Libnova south = 0, west = 90, north = 180, east = 270
-    horizontalPos.az = parkAZ + 180;
-    if (horizontalPos.az >= 360)
-        horizontalPos.az -= 360;
-    horizontalPos.alt = parkAlt;
-
-    ln_lnlat_posn observer;
-
-    observer.lat = LocationN[LOCATION_LATITUDE].value;
-    observer.lng = LocationN[LOCATION_LONGITUDE].value;
-
-    if (observer.lng > 180)
-        observer.lng -= 360;
-
-    ln_equ_posn equatorialPos;
-
-    ln_get_equ_from_hrz(&horizontalPos, &observer, ln_get_julian_from_sys(), &equatorialPos);
-
-    char RAStr[16], DEStr[16];
-    fs_sexa(RAStr, equatorialPos.ra/15.0, 2, 3600);
-    fs_sexa(DEStr, equatorialPos.dec, 2, 3600);
-    DEBUGF(INDI::Logger::DBG_DEBUG, "Parking to RA (%s) DEC (%s)...", RAStr, DEStr);
-
-    if (Goto(equatorialPos.ra/15.0, equatorialPos.dec))
+    if (setAPObjectAZ(PortFD, parkAz) < 0 || (setAPObjectAlt(PortFD, parkAlt)) < 0)
     {
-        TrackState = SCOPE_PARKING;
-        DEBUG(INDI::Logger::DBG_SESSION, "Parking is in progress...");
-
-        return true;
-    }
-    else
+        DEBUG(INDI::Logger::DBG_ERROR, "Error setting Az/Alt.");
         return false;
+    }
+
+    int err=0;
+    /* Slew reads the '0', that is not the end of the slew */
+    if (err = Slew(PortFD))
+    {
+        DEBUGF(INDI::Logger::DBG_ERROR, "Error Slewing to Az %s - Alt %s", AzStr, AltStr);
+        slewError(err);
+        return  false;
+    }
+
+    EqNP.s    = IPS_BUSY;
+    TrackState = SCOPE_PARKING;
+    DEBUG(INDI::Logger::DBG_SESSION, "Parking is in progress...");
+
+    return true;
 }
 
 bool LX200AstroPhysics::UnPark()
@@ -832,55 +838,30 @@ bool LX200AstroPhysics::UnPark()
         }
     }
 
-    return true;
-
-    // TODO need testing. If we unpark, do we get last parking position back? or we need to sync explicitly?
-
-    /*
-
     // Then we sync with to our last stored position
-    double parkAZ  = GetAxis1Park();
+    double parkAz  = GetAxis1Park();
     double parkAlt = GetAxis2Park();
 
     char AzStr[16], AltStr[16];
-    fs_sexa(AzStr, parkAZ, 2, 3600);
+    fs_sexa(AzStr, parkAz, 2, 3600);
     fs_sexa(AltStr, parkAlt, 2, 3600);
-    DEBUGF(INDI::Logger::DBG_DEBUG, "Unparking from Az (%s) Alt (%s)...", AzStr, AltStr);
+    DEBUGF(INDI::Logger::DBG_DEBUG, "Syncing to parked coordinates Az (%s) Alt (%s)...", AzStr, AltStr);
 
-    ln_hrz_posn horizontalPos;
-    // Libnova south = 0, west = 90, north = 180, east = 270
-    horizontalPos.az = parkAZ + 180;
-    if (horizontalPos.az >= 360)
-        horizontalPos.az -= 360;
-    horizontalPos.alt = parkAlt;
-
-    ln_lnlat_posn observer;
-
-    observer.lat = LocationN[LOCATION_LATITUDE].value;
-    observer.lng = LocationN[LOCATION_LONGITUDE].value;
-
-    if (observer.lng > 180)
-        observer.lng -= 360;
-
-    ln_equ_posn equatorialPos;
-
-    ln_get_equ_from_hrz(&horizontalPos, &observer, ln_get_julian_from_sys(), &equatorialPos);
-
-    char RAStr[16], DEStr[16];
-    fs_sexa(RAStr, equatorialPos.ra/15.0, 2, 3600);
-    fs_sexa(DEStr, equatorialPos.dec, 2, 3600);
-    DEBUGF(INDI::Logger::DBG_DEBUG, "Syncing to parked coordinates RA (%s) DEC (%s)...", RAStr, DEStr);
-
-    if (Sync(equatorialPos.ra/15.0, equatorialPos.dec))
+    if (setAPObjectAZ(PortFD, parkAz) < 0 || (setAPObjectAlt(PortFD, parkAlt)) < 0)
     {
-        SetParked(false);
-        return true;
-    }
-    else
+        DEBUG(INDI::Logger::DBG_ERROR, "Error setting Az/Alt.");
         return false;
+    }
 
-        */
+    char syncString[256];
+    if (APSyncCM(PortFD, syncString) < 0)
+    {
+        DEBUG(INDI::Logger::DBG_WARNING , "Sync failed.");
+        return false;
+    }
 
+    SetParked(false);
+    return true;
 }
 
 void LX200AstroPhysics::SetCurrentPark()
@@ -916,10 +897,10 @@ void LX200AstroPhysics::SetCurrentPark()
 
 void LX200AstroPhysics::SetDefaultPark()
 {
-    // By defualt azimuth 0
-    SetAxis1Park(0);
+    // Az = 0 for North hemisphere
+    SetAxis1Park(LocationN[LOCATION_LATITUDE].value > 0 ? 0 : 180);
 
-    // Altitude = latitude of observer
+    // Alt = Latitude
     SetAxis2Park(LocationN[LOCATION_LATITUDE].value);
 }
 
