@@ -1,6 +1,6 @@
 #if 0
     LX200 Generic
-    Copyright (C) 2003-2013 Jasem Mutlaq (mutlaqja@ikarustech.com)
+    Copyright (C) 2003-2015 Jasem Mutlaq (mutlaqja@ikarustech.com)
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -17,6 +17,7 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
     2013-10-27: Updated driver to use INDI::Telescope (JM)
+    2015-11-25: Use variable updatePeriodMS instead of static POLLMS
 
 #endif
 
@@ -40,10 +41,13 @@
 #include "lx200classic.h"
 #include "lx200ap.h"
 #include "lx200gemini.h"
+#include "lx200zeq25.h"
+#include "lx200pulsar2.h"
 #include "lx200fs2.h"
-
+#include "lx200ss2000pc.h"
+					       
 // We declare an auto pointer to LX200Generic.
-std::auto_ptr<LX200Generic> telescope(0);
+std::unique_ptr<LX200Generic> telescope;
 
 /* There is _one_ binary for all LX200 drivers, but each binary is renamed
 ** to its device name (i.e. lx200gps, lx200_16..etc). The main function will
@@ -116,6 +120,25 @@ void ISInit()
       if(telescope.get() == 0) telescope.reset(new LX200Gemini());
 
  }
+ else if (strstr(me, "indi_lx200zeq25"))
+ {
+       IDLog("initializing from ZEQ25 device...\n");
+
+       if(telescope.get() == 0) telescope.reset(new LX200ZEQ25());
+
+ }
+ else if (strstr(me, "indi_lx200pulsar2"))
+ {
+        IDLog("initializing from pulsar2 device...\n");
+
+        if(telescope.get() == 0) telescope.reset(new LX200Pulsar2());
+ }
+ else if (strstr(me, "indi_lx200ss2000pc"))
+ {
+        IDLog("initializing from skysensor2000pc device...\n");
+
+        if(telescope.get() == 0) telescope.reset(new LX200SS2000PC());
+ }
  else if (strstr(me, "indi_lx200fs2"))
  {
        IDLog("initializing from Astro-Electronic FS-2...\n");
@@ -183,20 +206,14 @@ LX200Generic::LX200Generic()
    GuideNSTID     = 0;
    GuideWETID     = 0;
 
+   updatePeriodMS = 1000;
+
    DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");
 
    currentRA=ln_get_apparent_sidereal_time(ln_get_julian_from_sys());
-   currentDEC=90;
+   currentDEC=90;  
 
-   TelescopeCapability cap;
-
-   cap.canPark = true;
-   cap.canSync = true;
-   cap.canAbort = true;
-   cap.hasTime = true;
-   cap.hasLocation = true;
-   cap.nSlewRate=4;
-   SetTelescopeCapability(&cap);
+   SetTelescopeCapability(TELESCOPE_CAN_PARK | TELESCOPE_CAN_SYNC | TELESCOPE_CAN_ABORT | TELESCOPE_HAS_TIME | TELESCOPE_HAS_LOCATION,4);
 
    DEBUG(INDI::Logger::DBG_DEBUG, "Initializing from Generic LX200 device...");
 }
@@ -274,7 +291,7 @@ bool LX200Generic::initProperties()
     /* Add debug/simulation/config controls so we may debug driver if necessary */
     addAuxControls();
 
-    setInterfaceDescriptor(getInterfaceDescriptor() | GUIDER_INTERFACE);
+    setDriverInterface(getDriverInterface() | GUIDER_INTERFACE);
 
     return true;
 }
@@ -361,7 +378,7 @@ bool LX200Generic::Connect()
     rc=Connect(PortT[0].text, atoi(IUFindOnSwitch(&BaudRateSP)->name));
 
     if(rc)
-        SetTimer(POLLMS);
+        SetTimer(updatePeriodMS);
 
     return rc;
 }
@@ -371,7 +388,7 @@ bool LX200Generic::checkConnection()
     return (check_lx200_connection(PortFD) == 0);
 }
 
-bool LX200Generic::Connect(const char *port, uint16_t baud)
+bool LX200Generic::Connect(const char *port, uint32_t baud)
 {
     if (isSimulation())
     {
@@ -462,7 +479,6 @@ bool LX200Generic::ReadScopeStatus()
 
 bool LX200Generic::Goto(double r,double d)
 {
-
     targetRA=r;
     targetDEC=d;
     char RAStr[64], DecStr[64];
@@ -522,7 +538,8 @@ bool LX200Generic::Goto(double r,double d)
     TrackState = SCOPE_SLEWING;
     EqNP.s    = IPS_BUSY;
 
-    IDMessage(getDeviceName(), "Slewing to RA: %s - DEC: %s", RAStr, DecStr);
+    DEBUGF(INDI::Logger::DBG_SESSION, "Slewing to RA: %s - DEC: %s", RAStr, DecStr);
+
     return true;
 }
 
@@ -712,7 +729,7 @@ bool LX200Generic::Abort()
      IDSetSwitch(&MovementWESP, NULL);
      IDSetNumber(&EqNP, NULL);
 
-     if (capability.canPark)
+     if (CanPark())
      {
         IUResetSwitch(&ParkSP);
         ParkSP.s = IPS_IDLE;
