@@ -1,3 +1,21 @@
+/*******************************************************************************
+ Copyright(c) 2015 Jasem Mutlaq. All rights reserved.
+
+ This library is free software; you can redistribute it and/or
+ modify it under the terms of the GNU Library General Public
+ License version 2 as published by the Free Software Foundation.
+ .
+ This library is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ Library General Public License for more details.
+ .
+ You should have received a copy of the GNU Library General Public License
+ along with this library; see the file COPYING.LIB.  If not, write to
+ the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ Boston, MA 02110-1301, USA.
+*******************************************************************************/
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -12,7 +30,7 @@
 #include <memory>
 
 // We declare an auto pointer to ScopeSim.
-std::auto_ptr<ScopeSim> telescope_sim(0);
+std::unique_ptr<ScopeSim> telescope_sim(new ScopeSim());
 
 #define	GOTO_RATE	5				/* slew rate, degrees/s */
 #define	SLEW_RATE	0.5				/* slew rate, degrees/s */
@@ -37,40 +55,23 @@ std::auto_ptr<ScopeSim> telescope_sim(0);
 
 void ISPoll(void *p);
 
-void ISInit()
-{
-   static int isInit =0;
-
-   if (isInit == 1)
-       return;
-
-    isInit = 1;
-    if(telescope_sim.get() == 0) telescope_sim.reset(new ScopeSim());
-    //IEAddTimer(POLLMS, ISPoll, NULL);
-
-}
-
 void ISGetProperties(const char *dev)
 {
-        ISInit();
         telescope_sim->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-        ISInit();
         telescope_sim->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-        ISInit();
         telescope_sim->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-        ISInit();
         telescope_sim->ISNewNumber(dev, name, values, names, num);
 }
 
@@ -90,7 +91,6 @@ void ISSnoopDevice (XMLEle *root)
    telescope_sim->ISSnoopDevice(root);
 }
 
-
 ScopeSim::ScopeSim()
 {
     //ctor
@@ -99,17 +99,9 @@ ScopeSim::ScopeSim()
 
     forceMeridianFlip = false;
 
-    DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");
+    DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");   
 
-    TelescopeCapability cap;
-
-    cap.canPark = true;
-    cap.canSync = true;
-    cap.canAbort = true;
-    cap.hasLocation = true;
-    cap.hasTime = true;
-    cap.nSlewRate=4;
-    SetTelescopeCapability(&cap);       
+    SetTelescopeCapability(TELESCOPE_CAN_PARK | TELESCOPE_CAN_SYNC | TELESCOPE_CAN_ABORT | TELESCOPE_HAS_TIME | TELESCOPE_HAS_LOCATION,4);
 
     /* initialize random seed: */
       srand ( time(NULL) );
@@ -171,7 +163,7 @@ bool ScopeSim::initProperties()
     /* Add debug controls so we may debug driver if necessary */
     addDebugControl();
 
-    setInterfaceDescriptor(getInterfaceDescriptor() | GUIDER_INTERFACE);
+    setDriverInterface(getDriverInterface() | GUIDER_INTERFACE);
 
     return true;
 }
@@ -254,7 +246,7 @@ bool ScopeSim::Connect()
     return rc;
 }
 
-bool ScopeSim::Connect(const char *port, uint16_t baud)
+bool ScopeSim::Connect(const char *port, uint32_t baud)
 {
    DEBUGF(INDI::Logger::DBG_SESSION, "Simulating connecting to port %s with speed %d", port, baud);
    DEBUG(INDI::Logger::DBG_SESSION, "Telescope simulator is online.");
@@ -616,10 +608,8 @@ bool ScopeSim::Sync(double ra, double dec)
 
     DEBUG(INDI::Logger::DBG_SESSION,"Sync is successful.");
 
-    TrackState = SCOPE_IDLE;
     EqNP.s    = IPS_OK;
 
-
     NewRaDec(currentRA, currentDEC);
 
     return true;
