@@ -1,3 +1,21 @@
+/*******************************************************************************
+ Copyright(c) 2015 Jasem Mutlaq. All rights reserved.
+
+ This library is free software; you can redistribute it and/or
+ modify it under the terms of the GNU Library General Public
+ License version 2 as published by the Free Software Foundation.
+ .
+ This library is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ Library General Public License for more details.
+ .
+ You should have received a copy of the GNU Library General Public License
+ along with this library; see the file COPYING.LIB.  If not, write to
+ the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ Boston, MA 02110-1301, USA.
+*******************************************************************************/
+
 #ifndef SCOPESIM_H
 #define SCOPESIM_H
 
@@ -13,7 +31,7 @@ public:
 
     virtual const char *getDefaultName();
     virtual bool Connect();
-    virtual bool Connect(const char *port, uint16_t baud);
+    virtual bool Connect(const char *port, uint32_t baud);
     virtual bool Disconnect();
     virtual bool ReadScopeStatus();
     virtual bool initProperties();
