@@ -16,46 +16,30 @@ using namespace INDI::AlignmentSubsystem;
 #define POLLMS 1000 // Default timer tick
 
 // We declare an auto pointer to ScopeSim.
-std::auto_ptr<ScopeSim> telescope_sim(0);
-
-void ISInit()
-{
-   static int isInit = 0;
-
-   if (isInit == 1)
-       return;
-
-    isInit = 1;
-    if(telescope_sim.get() == 0) telescope_sim.reset(new ScopeSim());
-}
+std::unique_ptr<ScopeSim> telescope_sim(new ScopeSim());
 
 void ISGetProperties(const char *dev)
 {
-        ISInit();
-        telescope_sim->ISGetProperties(dev);
+    telescope_sim->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-        ISInit();
-        telescope_sim->ISNewSwitch(dev, name, states, names, num);
+    telescope_sim->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-        ISInit();
-        telescope_sim->ISNewText(dev, name, texts, names, num);
+    telescope_sim->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-        ISInit();
-        telescope_sim->ISNewNumber(dev, name, values, names, num);
+    telescope_sim->ISNewNumber(dev, name, values, names, num);
 }
 
 void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[], char *names[], int n)
 {
-    ISInit();
     telescope_sim->ISNewBLOB (dev, name, sizes, blobsizes, blobs, formats, names, n);
 }
 
