@@ -33,39 +33,25 @@ const float TEMP_THRESHOLD = .25;		/* Differential temperature threshold (C)*/
 /* Macro shortcut to CCD temperature value */
 #define currentCCDTemperature   TemperatureN[0].value
 
-std::auto_ptr<SimpleCCD> simpleCCD(0);
-
-void ISInit()
-{
-    static int isInit =0;
-    if (isInit == 1)
-        return;
-
-     isInit = 1;
-     if(simpleCCD.get() == 0) simpleCCD.reset(new SimpleCCD());
-}
+std::unique_ptr<SimpleCCD> simpleCCD(new SimpleCCD());
 
 void ISGetProperties(const char *dev)
 {
-         ISInit();
          simpleCCD->ISGetProperties(dev);
 }
 
 void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int num)
 {
-         ISInit();
          simpleCCD->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
-         ISInit();
          simpleCCD->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
-         ISInit();
          simpleCCD->ISNewNumber(dev, name, values, names, num);
 }
 
@@ -83,11 +69,9 @@ void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[],
 
 void ISSnoopDevice (XMLEle *root)
 {
-     ISInit();
      simpleCCD->ISSnoopDevice(root);
 }
 
-
 SimpleCCD::SimpleCCD()
 {
     InExposure = false;
@@ -132,18 +116,8 @@ bool SimpleCCD::initProperties()
     INDI::CCD::initProperties();
 
     // We set the CCD capabilities
-    CCDCapability cap;
-
-    cap.canAbort = true;
-    cap.canBin   = true;
-    cap.canSubFrame = true;
-    cap.hasCooler = true;
-    cap.hasGuideHead = false;
-    cap.hasShutter = true;
-    cap.hasST4Port = false;
-    cap.hasBayer = false;
-
-    SetCCDCapability(&cap);
+    uint32_t cap = CCD_CAN_ABORT | CCD_CAN_BIN | CCD_CAN_SUBFRAME | CCD_HAS_COOLER | CCD_HAS_SHUTTER;
+    SetCCDCapability(cap);
 
     // Add Debug, Simulator, and Configuration controls
     addAuxControls();
@@ -321,7 +295,7 @@ void SimpleCCD::TimerHit()
 void SimpleCCD::grabImage()
 {
    // Let's get a pointer to the frame buffer
-   char * image = PrimaryCCD.getFrameBuffer();
+   uint8_t * image = PrimaryCCD.getFrameBuffer();
 
    // Get width and height
    int width = PrimaryCCD.getSubW() / PrimaryCCD.getBinX() * PrimaryCCD.getBPP()/8;
