@@ -42,6 +42,10 @@ INDI::BaseClient::BaseClient()
     cPort   = 7624;
     svrwfp = NULL;    
     sConnected = false;
+    verbose = false;
+
+    timeout_sec=3;
+    timeout_us=0;
 
 }
 
@@ -67,10 +71,14 @@ void INDI::BaseClient::watchDevice(const char * deviceName)
 
 bool INDI::BaseClient::connectServer()
 {
+    struct timeval ts;
+    ts.tv_sec = timeout_sec;
+    ts.tv_usec =timeout_us;
+
     struct sockaddr_in serv_addr;
     struct hostent *hp;
     int pipefd[2];
-    int ret = 0;
+    int ret = 0;    
 
     /* lookup host address */
     hp = gethostbyname(cServer.c_str());
@@ -91,10 +99,67 @@ bool INDI::BaseClient::connectServer()
         return false;
     }
 
+    /* set the socket in non-blocking */
+    //set socket nonblocking flag
+    int flags = 0;
+    if ( (flags = fcntl(sockfd, F_GETFL, 0)) < 0)
+       return false;
+
+     if(fcntl(sockfd, F_SETFL, flags | O_NONBLOCK) < 0)
+            return false;
+
+     //clear out descriptor sets for select
+     //add socket to the descriptor sets
+     fd_set  rset, wset;
+     FD_ZERO(&rset);
+     FD_SET(sockfd, &rset);
+     wset = rset;    //structure assignment okok
+
     /* connect */
-    if (::connect (sockfd,(struct sockaddr *)&serv_addr,sizeof(serv_addr))<0)
+    if ( (ret = ::connect (sockfd,(struct sockaddr *)&serv_addr,sizeof(serv_addr))) <0)
     {
-        perror ("connect");
+        if (errno != EINPROGRESS)
+        {
+            perror("connect");
+            close(sockfd);
+            return false;
+        }
+    }
+
+    /* If it is connected, continue, otherwise wait */
+    if (ret != 0)
+    {
+        //we are waiting for connect to complete now
+         if( (ret = select(sockfd + 1, &rset, &wset, NULL, &ts)) < 0)
+                return false;
+            //we had a timeout
+            if(ret == 0)
+            {
+                errno = ETIMEDOUT;
+                perror("select timeout");
+                return false;
+            }
+    }
+
+    /* we had a positivite return so a descriptor is ready */
+    int error=0;
+    socklen_t len = sizeof(error);
+    if (FD_ISSET(sockfd, &rset) || FD_ISSET(sockfd, &wset))
+    {
+        if(getsockopt(sockfd, SOL_SOCKET, SO_ERROR, &error, &len) < 0)
+        {
+               perror("getsockopt");
+               return false;
+        }
+    }
+    else
+        return false;
+
+    /* check if we had a socket error */
+    if(error)
+    {
+        errno = error;
+        perror("socket");        
         return false;
     }
 
@@ -118,15 +183,18 @@ bool INDI::BaseClient::connectServer()
     m_receiveFd = pipefd[0];
     m_sendFd = pipefd[1];
 
+    sConnected = true;
+
     int result = pthread_create( &listen_thread, NULL, &INDI::BaseClient::listenHelper, this);
 
     if (result != 0)
     {
+        sConnected = false;
         perror("thread");
         return false;
     }
 
-    sConnected = true;
+
     serverConnected();
 
     return true;
@@ -241,12 +309,20 @@ void INDI::BaseClient::listenINDI()
 
     setlocale(LC_NUMERIC,"C");
     if (cDeviceNames.empty())
+    {
        fprintf(svrwfp, "<getProperties version='%g'/>\n", INDIV);
+       if (verbose)
+           fprintf(stderr, "<getProperties version='%g'/>\n", INDIV);
+    }
     else
     {
         vector<string>::const_iterator stri;
         for ( stri = cDeviceNames.begin(); stri != cDeviceNames.end(); stri++)
+        {
             fprintf(svrwfp, "<getProperties version='%g' device='%s'/>\n", INDIV, (*stri).c_str());
+            if (verbose)
+                fprintf(stderr, "<getProperties version='%g' device='%s'/>\n", INDIV, (*stri).c_str());
+        }
     }
     setlocale(LC_NUMERIC,"");
 
@@ -304,12 +380,13 @@ void INDI::BaseClient::listenINDI()
 
             for (int i=0; i < n; i++)
             {
-              // IDLog("Getting #%d bytes in for loop, calling readXMLEle for byte %d\n", n, i);
-                XMLEle *root = readXMLEle (lillp, buffer[i], msg);
-                //IDLog("############# BLOCK # POST READ XML ELE #####################\n");
+               XMLEle *root = readXMLEle (lillp, buffer[i], msg);
 
                 if (root)
                 {
+                    if (verbose)
+                        prXMLEle(stderr, root, 0);
+
                     if ( (err_code = dispatchCommand(root, msg)) < 0)
                     {
                          // Silenty ignore property duplication errors
@@ -320,6 +397,7 @@ void INDI::BaseClient::listenINDI()
                          }
                     }
 
+
                    delXMLEle (root);	// not yet, delete and continue
                 }
                 else if (msg[0])
@@ -328,6 +406,8 @@ void INDI::BaseClient::listenINDI()
                    return;
                 }
             }
+
+
         }
 
     }
@@ -494,6 +574,12 @@ INDI::BaseDevice * INDI::BaseClient::findDev (XMLEle *root, int create, char * e
 
     dn = valuXMLAtt(ap);
 
+    if (*dn == '\0')
+    {
+        snprintf(errmsg, MAXRBUF, "Device name is empty! %s", tagXMLEle(root));
+        return (NULL);
+    }
+
     dp = findDev(dn, errmsg);
 
     if (dp)
