@@ -60,7 +60,7 @@ INDI::DefaultDevice::DefaultDevice()
 
     majorVersion = 1;
     minorVersion = 0;
-
+    interfaceDescriptor = GENERAL_INTERFACE;
 }
 
 INDI::DefaultDevice::~DefaultDevice()
@@ -600,12 +600,12 @@ bool INDI::DefaultDevice::updateProperties()
     return true;
 }
 
-unsigned int INDI::DefaultDevice::getInterfaceDescriptor() const
+uint16_t INDI::DefaultDevice::getDriverInterface()
 {
     return interfaceDescriptor;
 }
 
-void INDI::DefaultDevice::setInterfaceDescriptor(unsigned int value)
+void INDI::DefaultDevice::setDriverInterface(uint16_t value)
 {
     char interfaceStr[16];
     interfaceDescriptor = value;
@@ -663,6 +663,13 @@ bool INDI::DefaultDevice::deleteProperty(const char *propertyName)
 {
     char errmsg[MAXRBUF];
 
+    if (propertyName == NULL)
+    {
+        //while(!pAll.empty()) delete bar.back(), bar.pop_back();
+        IDDelete(getDeviceName(), NULL, NULL);
+        return true;
+    }
+
     if (removeProperty(propertyName, errmsg) == 0)
     {
         IDDelete(getDeviceName(), propertyName ,NULL);
