@@ -27,6 +27,7 @@
 #include <string.h>
 #include <time.h>
 #include <sys/time.h>
+#include <sys/stat.h>
 #include <zlib.h>
 #include <errno.h>
 #include <dirent.h>
@@ -34,6 +35,12 @@
 #include <libnova.h>
 #include <fitsio.h>
 
+#ifdef __linux__
+#include "webcam/v4l2_record/stream_recorder.h"
+#else
+class StreamRecorder {};
+#endif
+
 const char *IMAGE_SETTINGS_TAB  = "Image Settings";
 const char *IMAGE_INFO_TAB      = "Image Info";
 const char *GUIDE_HEAD_TAB      = "Guider Head";
@@ -46,12 +53,14 @@ CCDChip::CCDChip()
     SendCompressed=false;
     Interlaced=false;
 
-    RawFrame= (char *) malloc(sizeof(char)); // Seed for realloc
+    RawFrame= (uint8_t *) malloc(sizeof(uint8_t)); // Seed for realloc
     RawFrameSize=0;
 
     BPP = 8;
     BinX = BinY = 1;
-    NAxis = 2;
+    NAxis = 2;    
+
+    BinFrame = NULL;
 
     strncpy(imageExtention, "fits", MAXINDIBLOBFMT);
 
@@ -61,10 +70,10 @@ CCDChip::CCDChip()
 
 CCDChip::~CCDChip()
 {
-    delete RawFrame;
+    free(RawFrame);
     RawFrameSize=0;
     RawFrame=NULL;
-
+    free (BinFrame);
 }
 
 void CCDChip::setFrameType(CCD_FRAME type)
@@ -181,7 +190,10 @@ void CCDChip::setFrameBufferSize(int nbuf, bool allocMem)
     if (allocMem == false)
         return;
 
-    RawFrame = (char *) realloc(RawFrame, nbuf * sizeof(char));
+    RawFrame = (uint8_t *) realloc(RawFrame, nbuf * sizeof(uint8_t));
+
+    if (BinFrame)
+        BinFrame = (uint8_t *) realloc(BinFrame, nbuf * sizeof(uint8_t));
 }
 
 void CCDChip::setExposureLeft(double duration)
@@ -240,17 +252,82 @@ void CCDChip::setImageExtension(const char *ext)
     strncpy(imageExtention, ext, MAXINDIBLOBFMT);
 }
 
+void CCDChip::binFrame()
+{
+    if (BinX == 1)
+        return;
+
+    // Jasem: Keep full frame shadow in memory to enhance performance and just swap frame pointers after operation is complete
+    if (BinFrame == NULL)
+        BinFrame = (uint8_t*) malloc(RawFrameSize);
+
+    memset(BinFrame, 0, RawFrameSize);
+
+    switch (getBPP())
+    {
+    case 8:
+    {
+        uint8_t *bin_buf = BinFrame;
+        uint8_t val;
+        for (int i=0; i < SubH; i+= BinX)
+            for (int j=0; j < SubW; j+= BinX)
+            {
+                for (int k=0; k < BinX; k++)
+                {
+                    for (int l=0; l < BinX; l++)
+                    {
+                        val = *(RawFrame + j + (i+k) * SubW + l);
+                        if (val + *bin_buf > UINT8_MAX)
+                            *bin_buf = UINT8_MAX;
+                        else
+                            *bin_buf  += val;
+                    }
+                }
+                bin_buf++;
+            }
+    }
+    break;
+
+    case 16:
+    {
+        uint16_t *bin_buf = (uint16_t*) BinFrame;
+        uint16_t *RawFrame16 = (uint16_t*) RawFrame;
+        uint16_t val;
+        for (int i=0; i < SubH; i+= BinX)
+            for (int j=0; j < SubW; j+= BinX)
+            {
+                for (int k=0; k < BinX; k++)
+                {
+                    for (int l=0; l < BinX; l++)
+                    {
+                        val = *(RawFrame16 + j + (i+k) * SubW + l);
+                        if (val + *bin_buf > UINT16_MAX)
+                            *bin_buf = UINT16_MAX;
+                        else
+                            *bin_buf  += val;
+                    }
+                }
+                bin_buf++;
+            }
+    }
+    break;
+
+    default:
+        return;
+
+    }
+
+    // Swap frame pointers
+    uint8_t *rawFramePointer = RawFrame;
+    RawFrame = BinFrame;
+    // We just memset it next time we use it
+    BinFrame = rawFramePointer;
+}
+
 INDI::CCD::CCD()
 {
     //ctor
-    capability.hasGuideHead=false;
-    capability.hasST4Port=false;
-    capability.hasShutter=false;
-    capability.hasCooler=false;
-    capability.canBin=false;
-    capability.canSubFrame=false;
-    capability.canAbort=false;
-    capability.hasBayer;
+    capability = 0;
 
     InExposure=false;
     InGuideExposure=false;
@@ -272,23 +349,33 @@ INDI::CCD::CCD()
     RA=-1000;
     Dec=-1000;
     Aperture=FocalLength=-1;
+
+    streamer = NULL;
 }
 
 INDI::CCD::~CCD()
 {
-
+    delete (streamer);
 }
 
-void INDI::CCD::SetCCDCapability(CCDCapability *cap)
+void INDI::CCD::SetCCDCapability(uint32_t cap)
 {
-    capability.canAbort     = cap->canAbort;
-    capability.canBin       = cap->canBin;
-    capability.canSubFrame  = cap->canSubFrame;
-    capability.hasCooler    = cap->hasCooler;
-    capability.hasGuideHead = cap->hasGuideHead;
-    capability.hasShutter   = cap->hasShutter;
-    capability.hasST4Port   = cap->hasST4Port;
-    capability.hasBayer     = cap->hasBayer;
+    capability = cap;
+
+    if (HasGuideHead())
+        setDriverInterface(getDriverInterface() | GUIDER_INTERFACE);
+    else
+        setDriverInterface(getDriverInterface() & ~GUIDER_INTERFACE);
+
+#ifdef __linux__
+    if (HasStreaming() && streamer == NULL)
+    {
+        delete (streamer);
+        streamer = new StreamRecorder(this);
+        streamer->initProperties();
+    }
+#endif
+
 }
 
 bool INDI::CCD::initProperties()
@@ -453,21 +540,26 @@ bool INDI::CCD::initProperties()
     IDSnoopDevice(ActiveDeviceT[2].text,"FILTER_NAME");
 
     // Guider Interface
-    initGuiderProperties(getDeviceName(), GUIDE_CONTROL_TAB);
+    initGuiderProperties(getDeviceName(), GUIDE_CONTROL_TAB);        
 
-    setInterfaceDescriptor(CCD_INTERFACE|GUIDER_INTERFACE);
+    setDriverInterface(CCD_INTERFACE|GUIDER_INTERFACE);
 
     return true;
 }
 
 void INDI::CCD::ISGetProperties (const char *dev)
-{
-    //  First we let our parent populate
-
-    //IDLog("INDI::CCD IsGetProperties with %s\n",dev);
-
+{    
     DefaultDevice::ISGetProperties(dev);
 
+    defineText(&ActiveDeviceTP);
+    loadConfig(true, "ACTIVE_DEVICES");
+
+    // Streamer
+    #ifdef __linux__
+    if (HasStreaming())
+        streamer->ISGetProperties(dev);
+    #endif
+
     return;
 }
 
@@ -478,61 +570,61 @@ bool INDI::CCD::updateProperties()
     {
        defineNumber(&PrimaryCCD.ImageExposureNP);
 
-       if (capability.canAbort)
+       if (CanAbort())
             defineSwitch(&PrimaryCCD.AbortExposureSP);
-       if (capability.canSubFrame == false)
+       if (CanSubFrame() == false)
            PrimaryCCD.ImageFrameNP.p = IP_RO;
 
         defineNumber(&PrimaryCCD.ImageFrameNP);
-       if (capability.canBin)
+       if (CanBin())
             defineNumber(&PrimaryCCD.ImageBinNP);
 
-        if(capability.hasGuideHead)
+        if(HasGuideHead())
         {
             defineNumber(&GuideCCD.ImageExposureNP);
-            if (capability.canAbort)
+            if (CanAbort())
                 defineSwitch(&GuideCCD.AbortExposureSP);
-            if (capability.canSubFrame == false)
+            if (CanSubFrame() == false)
                 GuideCCD.ImageFrameNP.p = IP_RO;
             defineNumber(&GuideCCD.ImageFrameNP);
         }
 
-        if (capability.hasCooler)
+        if (HasCooler())
             defineNumber(&TemperatureNP);
 
         defineNumber(&PrimaryCCD.ImagePixelSizeNP);
-        if(capability.hasGuideHead)
+        if(HasGuideHead())
         {
             defineNumber(&GuideCCD.ImagePixelSizeNP);
-            if (capability.canBin)
+            if (CanBin())
                 defineNumber(&GuideCCD.ImageBinNP);
         }
         defineSwitch(&PrimaryCCD.CompressSP);
         defineBLOB(&PrimaryCCD.FitsBP);
-        if(capability.hasGuideHead)
+        if(HasGuideHead())
         {
             defineSwitch(&GuideCCD.CompressSP);
             defineBLOB(&GuideCCD.FitsBP);
         }
-        if(capability.hasST4Port)
+        if(HasST4Port())
         {
             defineNumber(&GuideNSNP);
             defineNumber(&GuideWENP);
         }
         defineSwitch(&PrimaryCCD.FrameTypeSP);
 
-        if (capability.canBin || capability.canSubFrame)
+        if (CanBin() || CanSubFrame())
             defineSwitch(&PrimaryCCD.ResetSP);
 
-        if (capability.hasGuideHead)
+        if (HasGuideHead())
             defineSwitch(&GuideCCD.FrameTypeSP);
 
-        if (capability.hasBayer)
+        if (HasBayer())
             defineText(&BayerTP);
 
         defineSwitch(&PrimaryCCD.RapidGuideSP);
 
-        if (capability.hasGuideHead)
+        if (HasGuideHead())
           defineSwitch(&GuideCCD.RapidGuideSP);
 
         if (RapidGuideEnabled)
@@ -544,25 +636,24 @@ bool INDI::CCD::updateProperties()
         {
           defineSwitch(&GuideCCD.RapidGuideSetupSP);
           defineNumber(&GuideCCD.RapidGuideDataNP);
-        }
-        defineText(&ActiveDeviceTP);
+        }        
         defineSwitch(&WorldCoordSP);
         defineSwitch(&UploadSP);
 
         if (UploadSettingsT[0].text == NULL)
             IUSaveText(&UploadSettingsT[0], getenv("HOME"));
-        defineText(&UploadSettingsTP);
+        defineText(&UploadSettingsTP);                
     }
     else
     {
         deleteProperty(PrimaryCCD.ImageFrameNP.name);
         deleteProperty(PrimaryCCD.ImagePixelSizeNP.name);
 
-        if (capability.canBin)
+        if (CanBin())
             deleteProperty(PrimaryCCD.ImageBinNP.name);
 
         deleteProperty(PrimaryCCD.ImageExposureNP.name);
-        if (capability.canAbort)
+        if (CanAbort())
             deleteProperty(PrimaryCCD.AbortExposureSP.name);
         deleteProperty(PrimaryCCD.FitsBP.name);
         deleteProperty(PrimaryCCD.CompressSP.name);
@@ -572,16 +663,16 @@ bool INDI::CCD::updateProperties()
           deleteProperty(PrimaryCCD.RapidGuideSetupSP.name);
           deleteProperty(PrimaryCCD.RapidGuideDataNP.name);
         }
-        if(capability.hasGuideHead)
+        if(HasGuideHead())
         {
             deleteProperty(GuideCCD.ImageExposureNP.name);
-            if (capability.canAbort)
+            if (CanAbort())
                 deleteProperty(GuideCCD.AbortExposureSP.name);
                 deleteProperty(GuideCCD.ImageFrameNP.name);
                 deleteProperty(GuideCCD.ImagePixelSizeNP.name);
 
             deleteProperty(GuideCCD.FitsBP.name);
-            if (capability.canBin)
+            if (CanBin())
                 deleteProperty(GuideCCD.ImageBinNP.name);
             deleteProperty(GuideCCD.CompressSP.name);
             deleteProperty(GuideCCD.FrameTypeSP.name);
@@ -592,19 +683,18 @@ bool INDI::CCD::updateProperties()
               deleteProperty(GuideCCD.RapidGuideDataNP.name);
             }
         }
-        if (capability.hasCooler)
+        if (HasCooler())
             deleteProperty(TemperatureNP.name);
-        if(capability.hasST4Port)
+        if(HasST4Port())
         {
             deleteProperty(GuideNSNP.name);
             deleteProperty(GuideWENP.name);
         }
         deleteProperty(PrimaryCCD.FrameTypeSP.name);
-        if (capability.canBin || capability.canSubFrame)
+        if (CanBin() || CanSubFrame())
             deleteProperty(PrimaryCCD.ResetSP.name);
-        if (capability.hasBayer)
+        if (HasBayer())
             deleteProperty(BayerTP.name);
-        deleteProperty(ActiveDeviceTP.name);
         if (WorldCoordS[0].s == ISS_ON)
         {
             deleteProperty(TelescopeTypeSP.name);
@@ -614,6 +704,13 @@ bool INDI::CCD::updateProperties()
         deleteProperty(UploadSP.name);
         deleteProperty(UploadSettingsTP.name);
     }
+
+    // Streamer
+    #ifdef __linux__
+    if (HasStreaming())
+        streamer->updateProperties();
+    #endif
+
     return true;
 }
 
@@ -726,6 +823,12 @@ bool INDI::CCD::ISNewText (const char *dev, const char *name, char *texts[], cha
 
     }
 
+    // Streamer
+    #ifdef __linux__
+    if (HasStreaming())
+        streamer->ISNewText(dev,name,texts,names,n);
+    #endif
+
     return INDI::DefaultDevice::ISNewText(dev,name,texts,names,n);
 }
 
@@ -977,14 +1080,18 @@ bool INDI::CCD::ISNewNumber (const char *dev, const char *name, double values[],
             return true;
         }
     }
-    //  if we didn't process it, continue up the chain, let somebody else
-    //  give it a shot
+
+    // Streamer
+    #ifdef __linux__
+    if (HasStreaming())
+        streamer->ISNewNumber(dev,name,values,names,n);
+    #endif
+
     return DefaultDevice::ISNewNumber(dev,name,values,names,n);
 }
 
 bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n)
 {
-
     if(strcmp(dev,getDeviceName())==0)
     {
         if (!strcmp(name, UploadSP.name))
@@ -1036,9 +1143,9 @@ bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states,
         {
           IUResetSwitch(&PrimaryCCD.ResetSP);
           PrimaryCCD.ResetSP.s = IPS_OK;
-          if (capability.canBin)
+          if (CanBin())
               UpdateCCDBin(1,1);
-          if (capability.canSubFrame)
+          if (CanSubFrame())
               UpdateCCDFrame(0,0, PrimaryCCD.getXRes(), PrimaryCCD.getYRes());
 
           IDSetSwitch(&PrimaryCCD.ResetSP, NULL);
@@ -1132,13 +1239,13 @@ bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states,
             else if(PrimaryCCD.FrameTypeS[1].s==ISS_ON)
             {
                 PrimaryCCD.setFrameType(CCDChip::BIAS_FRAME);
-                if (capability.hasShutter == false)
+                if (HasShutter() == false)
                     DEBUG(INDI::Logger::DBG_WARNING, "The CCD does not have a shutter. Cover the camera in order to take a bias frame.");
             }
             else if(PrimaryCCD.FrameTypeS[2].s==ISS_ON)
             {
                 PrimaryCCD.setFrameType(CCDChip::DARK_FRAME);
-                if (capability.hasShutter == false)
+                if (HasShutter() == false)
                     DEBUG(INDI::Logger::DBG_WARNING, "The CCD does not have a shutter. Cover the camera in order to take a dark frame.");
             }
             else if(PrimaryCCD.FrameTypeS[3].s==ISS_ON)
@@ -1162,13 +1269,13 @@ bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states,
             else if(GuideCCD.FrameTypeS[1].s==ISS_ON)
             {
                 GuideCCD.setFrameType(CCDChip::BIAS_FRAME);
-                if (capability.hasShutter == false)
+                if (HasShutter() == false)
                     DEBUG(INDI::Logger::DBG_WARNING, "The CCD does not have a shutter. Cover the camera in order to take a bias frame.");
             }
             else if(GuideCCD.FrameTypeS[2].s==ISS_ON)
             {
                 GuideCCD.setFrameType(CCDChip::DARK_FRAME);
-                if (capability.hasShutter == false)
+                if (HasShutter() == false)
                     DEBUG(INDI::Logger::DBG_WARNING, "The CCD does not have a shutter. Cover the camera in order to take a dark frame.");
             }
             else if(GuideCCD.FrameTypeS[3].s==ISS_ON)
@@ -1248,7 +1355,12 @@ bool INDI::CCD::ISNewSwitch (const char *dev, const char *name, ISState *states,
         }
     }
 
-    // let the default driver have a crack at it
+    // Streamer
+    #ifdef __linux__
+    if (HasStreaming())
+        streamer->ISNewSwitch(dev, name, states, names, n);
+    #endif
+
     return DefaultDevice::ISNewSwitch(dev, name, states, names, n);
 }
 
@@ -1376,7 +1488,7 @@ void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
     if(targetChip->getFrameType() == CCDChip::DARK_FRAME)
         fits_update_key_s(fptr, TDOUBLE, "DARKTIME", &(exposureDuration), "Total Exposure Time (s)", &status);
 
-    if (capability.hasCooler)
+    if (HasCooler())
       fits_update_key_s(fptr, TDOUBLE, "CCD-TEMP" , &(TemperatureN[0].value), "CCD Temperature (Celcius)", &status);
 
     fits_update_key_s(fptr, TDOUBLE, "PIXSIZE1", &(pixSize1), "Pixel Size 1 (microns)", &status);
@@ -1397,7 +1509,7 @@ void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
         fits_update_key_s(fptr, TDOUBLE, "DATAMAX", &max_val, "Maximum value", &status);
     }
 
-    if (capability.hasBayer && targetChip->getNAxis() == 2)
+    if (HasBayer() && targetChip->getNAxis() == 2)
     {
         unsigned int bayer_offset_x = atoi(BayerT[0].text);
         unsigned int bayer_offset_y = atoi(BayerT[1].text);
@@ -1407,6 +1519,9 @@ void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
         fits_update_key_s(fptr, TSTRING, "BAYERPAT", BayerT[2].text, "Bayer color pattern", &status);
     }
 
+    if (FocalLength != -1)
+        fits_update_key_s(fptr, TDOUBLE, "FOCALLEN", &FocalLength, "Focal Length (mm)", &status);
+
     if (targetChip->getFrameType() == CCDChip::LIGHT_FRAME && RA != -1000 && Dec != -1000)
     {
         ln_equ_posn epochPos, J2000Pos;
@@ -1425,7 +1540,7 @@ void INDI::CCD::addFITSKeywords(fitsfile *fptr, CCDChip *targetChip)
 
         int epoch = 2000;
 
-        fits_update_key_s(fptr, TINT, "EPOCH", &epoch, "Epoch", &status);
+        //fits_update_key_s(fptr, TINT, "EPOCH", &epoch, "Epoch", &status);
         fits_update_key_s(fptr, TINT, "EQUINOX", &epoch, "Equinox", &status);
 
 
@@ -1509,7 +1624,7 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
     bool autoLoop = false;
     bool sendData = false;
 
-    if (RapidGuideEnabled && targetChip == &PrimaryCCD)
+    if (RapidGuideEnabled && targetChip == &PrimaryCCD && (PrimaryCCD.getBPP() == 16 || PrimaryCCD.getBPP() == 8))
     {
       autoLoop = AutoLoop;
       sendImage = SendImage;
@@ -1518,7 +1633,7 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
       saveImage = false;
     }
 
-    if (GuiderRapidGuideEnabled && targetChip == &GuideCCD)
+    if (GuiderRapidGuideEnabled && targetChip == &GuideCCD && (GuideCCD.getBPP() == 16 || PrimaryCCD.getBPP() == 8))
     {
       autoLoop = GuiderAutoLoop;
       sendImage = GuiderSendImage;
@@ -1533,11 +1648,10 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
       targetChip->RapidGuideDataNP.s=IPS_BUSY;
       int width = targetChip->getSubW() / targetChip->getBinX();
       int height = targetChip->getSubH() / targetChip->getBinY();
-      unsigned short *src = (unsigned short *) targetChip->getFrameBuffer();
+      void *src = (unsigned short *) targetChip->getFrameBuffer();
       int i0, i1, i2, i3, i4, i5, i6, i7, i8;
       int ix = 0, iy = 0;
       int xM4;
-      unsigned short *p;
       double average, fit, bestFit = 0;
       int minx = 4;
       int maxx = width -4;
@@ -1549,63 +1663,114 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
         miny = std::max(targetChip->lastRapidY - 20, 4);
         maxy = std::min(targetChip->lastRapidY + 20, height -4);
       }
-      for (int x = minx; x < maxx; x++)
-        for (int y = miny; y < maxy; y++)
-        {
-          i0 = i1 = i2 = i3 = i4 = i5 = i6 = i7 = i8 = 0;
-          xM4 = x - 4;
-          p = src + (y - 4) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
-          p = src + (y - 3) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i7 += *p++; i6 += *p++; i7 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
-          p = src + (y - 2) * width + xM4; i8 += *p++; i8 += *p++; i5 += *p++; i4 += *p++; i3 += *p++; i4 += *p++; i5 += *p++; i8 += *p++; i8 += *p++;
-          p = src + (y - 1) * width + xM4; i8 += *p++; i7 += *p++; i4 += *p++; i2 += *p++; i1 += *p++; i2 += *p++; i4 += *p++; i8 += *p++; i8 += *p++;
-          p = src + (y + 0) * width + xM4; i8 += *p++; i6 += *p++; i3 += *p++; i1 += *p++; i0 += *p++; i1 += *p++; i3 += *p++; i6 += *p++; i8 += *p++;
-          p = src + (y + 1) * width + xM4; i8 += *p++; i7 += *p++; i4 += *p++; i2 += *p++; i1 += *p++; i2 += *p++; i4 += *p++; i8 += *p++; i8 += *p++;
-          p = src + (y + 2) * width + xM4; i8 += *p++; i8 += *p++; i5 += *p++; i4 += *p++; i3 += *p++; i4 += *p++; i5 += *p++; i8 += *p++; i8 += *p++;
-          p = src + (y + 3) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i7 += *p++; i6 += *p++; i7 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
-          p = src + (y + 4) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
-          average = (i0 + i1 + i2 + i3 + i4 + i5 + i6 + i7 + i8) / 85.0;
-          fit = P0 * (i0 - average) + P1 * (i1 - 4 * average) + P2 * (i2 - 4 * average) + P3 * (i3 - 4 * average) + P4 * (i4 - 8 * average) + P5 * (i5 - 4 * average) + P6 * (i6 - 4 * average) + P7 * (i7 - 8 * average) + P8 * (i8 - 48 * average);
-          if (bestFit < fit)
-          {
-            bestFit = fit;
-            ix = x;
-            iy = y;
+      if (targetChip->getBPP() == 16) {
+        unsigned short *p;
+        for (int x = minx; x < maxx; x++)
+          for (int y = miny; y < maxy; y++) {
+            i0 = i1 = i2 = i3 = i4 = i5 = i6 = i7 = i8 = 0;
+            xM4 = x - 4;
+            p = (unsigned short *)src + (y - 4) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned short *)src + (y - 3) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i7 += *p++; i6 += *p++; i7 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned short *)src + (y - 2) * width + xM4; i8 += *p++; i8 += *p++; i5 += *p++; i4 += *p++; i3 += *p++; i4 += *p++; i5 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned short *)src + (y - 1) * width + xM4; i8 += *p++; i7 += *p++; i4 += *p++; i2 += *p++; i1 += *p++; i2 += *p++; i4 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned short *)src + (y + 0) * width + xM4; i8 += *p++; i6 += *p++; i3 += *p++; i1 += *p++; i0 += *p++; i1 += *p++; i3 += *p++; i6 += *p++; i8 += *p++;
+            p = (unsigned short *)src + (y + 1) * width + xM4; i8 += *p++; i7 += *p++; i4 += *p++; i2 += *p++; i1 += *p++; i2 += *p++; i4 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned short *)src + (y + 2) * width + xM4; i8 += *p++; i8 += *p++; i5 += *p++; i4 += *p++; i3 += *p++; i4 += *p++; i5 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned short *)src + (y + 3) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i7 += *p++; i6 += *p++; i7 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned short *)src + (y + 4) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
+            average = (i0 + i1 + i2 + i3 + i4 + i5 + i6 + i7 + i8) / 85.0;
+            fit = P0 * (i0 - average) + P1 * (i1 - 4 * average) + P2 * (i2 - 4 * average) + P3 * (i3 - 4 * average) + P4 * (i4 - 8 * average) + P5 * (i5 - 4 * average) + P6 * (i6 - 4 * average) + P7 * (i7 - 8 * average) + P8 * (i8 - 48 * average);
+            if (bestFit < fit) {
+              bestFit = fit;
+              ix = x;
+              iy = y;
+            }
           }
-        }
+      } else {
+        unsigned char *p;
+        for (int x = minx; x < maxx; x++)
+          for (int y = miny; y < maxy; y++) {
+            i0 = i1 = i2 = i3 = i4 = i5 = i6 = i7 = i8 = 0;
+            xM4 = x - 4;
+            p = (unsigned char *)src + (y - 4) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned char *)src + (y - 3) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i7 += *p++; i6 += *p++; i7 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned char *)src + (y - 2) * width + xM4; i8 += *p++; i8 += *p++; i5 += *p++; i4 += *p++; i3 += *p++; i4 += *p++; i5 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned char *)src + (y - 1) * width + xM4; i8 += *p++; i7 += *p++; i4 += *p++; i2 += *p++; i1 += *p++; i2 += *p++; i4 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned char *)src + (y + 0) * width + xM4; i8 += *p++; i6 += *p++; i3 += *p++; i1 += *p++; i0 += *p++; i1 += *p++; i3 += *p++; i6 += *p++; i8 += *p++;
+            p = (unsigned char *)src + (y + 1) * width + xM4; i8 += *p++; i7 += *p++; i4 += *p++; i2 += *p++; i1 += *p++; i2 += *p++; i4 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned char *)src + (y + 2) * width + xM4; i8 += *p++; i8 += *p++; i5 += *p++; i4 += *p++; i3 += *p++; i4 += *p++; i5 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned char *)src + (y + 3) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i7 += *p++; i6 += *p++; i7 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
+            p = (unsigned char *)src + (y + 4) * width + xM4; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++; i8 += *p++;
+            average = (i0 + i1 + i2 + i3 + i4 + i5 + i6 + i7 + i8) / 85.0;
+            fit = P0 * (i0 - average) + P1 * (i1 - 4 * average) + P2 * (i2 - 4 * average) + P3 * (i3 - 4 * average) + P4 * (i4 - 8 * average) + P5 * (i5 - 4 * average) + P6 * (i6 - 4 * average) + P7 * (i7 - 8 * average) + P8 * (i8 - 48 * average);
+            if (bestFit < fit) {
+              bestFit = fit;
+              ix = x;
+              iy = y;
+            }
+          }
+      }
 
       targetChip->RapidGuideDataN[0].value = ix;
       targetChip->RapidGuideDataN[1].value = iy;
       targetChip->RapidGuideDataN[2].value = bestFit;
       targetChip->lastRapidX = ix;
       targetChip->lastRapidY = iy;
-      if (bestFit > 50)
-      {
+      if (bestFit > 50) {
         int sumX = 0;
         int sumY = 0;
         int total = 0;
         int max = 0;
         int noiseThreshold = 0;
-        for (int y = iy - 4; y <= iy + 4; y++) {
-          p = src + y * width + ix - 4;
-          for (int x = ix - 4; x <= ix + 4; x++) {
-            int w = *p++;
-            noiseThreshold += w;
-            if (w > max)
-              max = w;
+        
+        if (targetChip->getBPP() == 16) {
+          unsigned short *p;
+          for (int y = iy - 4; y <= iy + 4; y++) {
+            p = (unsigned short *)src + y * width + ix - 4;
+            for (int x = ix - 4; x <= ix + 4; x++) {
+              int w = *p++;
+              noiseThreshold += w;
+              if (w > max)
+                max = w;
+            }
           }
-        }
-        noiseThreshold = (noiseThreshold/81+max)/2; // set threshold between peak and average
-        for (int y = iy - 4; y <= iy + 4; y++) {
-          p = src + y * width + ix - 4;
-          for (int x = ix - 4; x <= ix + 4; x++) {
-            int w = *p++;
-            if (w < noiseThreshold)
-              w = 0;
-            sumX += x * w;
-            sumY += y * w;
-            total += w;
+          noiseThreshold = (noiseThreshold/81+max)/2; // set threshold between peak and average
+          for (int y = iy - 4; y <= iy + 4; y++) {
+            p = (unsigned short *)src + y * width + ix - 4;
+            for (int x = ix - 4; x <= ix + 4; x++) {
+              int w = *p++;
+              if (w < noiseThreshold)
+                w = 0;
+              sumX += x * w;
+              sumY += y * w;
+              total += w;
+            }
+          }
+        } else {
+          unsigned char *p;
+          for (int y = iy - 4; y <= iy + 4; y++) {
+            p = (unsigned char *)src + y * width + ix - 4;
+            for (int x = ix - 4; x <= ix + 4; x++) {
+              int w = *p++;
+              noiseThreshold += w;
+              if (w > max)
+                max = w;
+            }
+          }
+          noiseThreshold = (noiseThreshold/81+max)/2; // set threshold between peak and average
+          for (int y = iy - 4; y <= iy + 4; y++) {
+            p = (unsigned char *)src + y * width + ix - 4;
+            for (int x = ix - 4; x <= ix + 4; x++) {
+              int w = *p++;
+              if (w < noiseThreshold)
+                w = 0;
+              sumX += x * w;
+              sumY += y * w;
+              total += w;
+            }
           }
         }
+        
         if (total > 0)
         {
           targetChip->RapidGuideDataN[0].value = ((double)sumX)/total;
@@ -1637,34 +1802,69 @@ bool INDI::CCD::ExposureComplete(CCDChip *targetChip)
 
         //fprintf(stderr, "%d %d %d %d\n", xmin, xmax, ymin, ymax);
 
-        if (ymin > 0)
-        {
-          p = src + ymin * width + xmin;
-          for (int x = xmin; x <= xmax; x++)
-            *p++ = 50000;
-        }
-
-        if (xmin > 0)
-        {
-          for (int y = ymin; y<= ymax; y++)
+        if (targetChip->getBPP() == 16) {
+          unsigned short *p;
+          if (ymin > 0)
           {
-            *(src + y * width + xmin) = 50000;
+            p = (unsigned short *)src + ymin * width + xmin;
+            for (int x = xmin; x <= xmax; x++)
+              *p++ = 50000;
           }
-        }
 
-        if (xmax < width - 1)
-        {
-          for (int y = ymin; y<= ymax; y++)
+          if (xmin > 0)
           {
-            *(src + y * width + xmax) = 50000;
+            for (int y = ymin; y<= ymax; y++)
+            {
+              *((unsigned short *)src + y * width + xmin) = 50000;
+            }
           }
-        }
 
-        if (ymax < height -1)
-        {
-          p = src + ymax * width + xmin;
-          for (int x = xmin; x <= xmax; x++)
-            *p++ = 50000;
+          if (xmax < width - 1)
+          {
+            for (int y = ymin; y<= ymax; y++)
+            {
+              *((unsigned short *)src + y * width + xmax) = 50000;
+            }
+          }
+
+          if (ymax < height -1)
+          {
+            p = (unsigned short *)src + ymax * width + xmin;
+            for (int x = xmin; x <= xmax; x++)
+              *p++ = 50000;
+          }
+        } else {
+          unsigned char *p;
+          if (ymin > 0)
+          {
+            p = (unsigned char *)src + ymin * width + xmin;
+            for (int x = xmin; x <= xmax; x++)
+              *p++ = 255;
+          }
+          
+          if (xmin > 0)
+          {
+            for (int y = ymin; y<= ymax; y++)
+            {
+              *((unsigned char *)src + y * width + xmin) = 255;
+            }
+          }
+          
+          if (xmax < width - 1)
+          {
+            for (int y = ymin; y<= ymax; y++)
+            {
+              *((unsigned char *)src + y * width + xmax) = 255;
+            }
+          }
+          
+          if (ymax < height -1)
+          {
+            p = (unsigned char *)src + ymax * width + xmin;
+            for (int x = xmin; x <= xmax; x++)
+              *p++ = 255;
+          }
+          
         }
       }
     }
@@ -1906,7 +2106,7 @@ void INDI::CCD::SetCCDParams(int x,int y,int bpp,float xf,float yf)
 {
     PrimaryCCD.setResolution(x, y);
     PrimaryCCD.setFrame(0, 0, x, y);
-    if (capability.canBin)
+    if (CanBin())
         PrimaryCCD.setBin(1,1);
     PrimaryCCD.setPixelSize(xf, yf);
     PrimaryCCD.setBPP(bpp);
@@ -1915,7 +2115,7 @@ void INDI::CCD::SetCCDParams(int x,int y,int bpp,float xf,float yf)
 
 void INDI::CCD::SetGuiderParams(int x,int y,int bpp,float xf,float yf)
 {
-    capability.hasGuideHead=true;
+    capability |= CCD_HAS_GUIDE_HEAD;
 
     GuideCCD.setResolution(x, y);
     GuideCCD.setFrame(0, 0, x, y);
@@ -1937,16 +2137,16 @@ bool INDI::CCD::saveConfigItems(FILE *fp)
 
     IUSaveConfigSwitch(fp, &PrimaryCCD.CompressSP);
 
-    if (capability.hasGuideHead)
+    if (HasGuideHead())
         IUSaveConfigSwitch(fp, &GuideCCD.CompressSP);
 
-    if (capability.canSubFrame)
+    if (CanSubFrame())
         IUSaveConfigNumber(fp, &PrimaryCCD.ImageFrameNP);
 
-    if (capability.canBin)
+    if (CanBin())
         IUSaveConfigNumber(fp, &PrimaryCCD.ImageBinNP);
 
-    if (capability.hasBayer)
+    if (HasBayer())
         IUSaveConfigText(fp, &BayerTP);
 
     return true;
@@ -2057,6 +2257,15 @@ int INDI::CCD::getFileIndex(const char *dir, const char *prefix, const char *ext
     std::string prefixSearch = prefix;
     prefixSearch.replace(prefixSearch.find("XXX"), 3, "");
 
+    // Create directory if does not exist
+    struct stat st = {0};
+    if (stat(dir, &st) == -1)
+    {
+       DEBUGF(INDI::Logger::DBG_DEBUG, "Creating directory %s...", dir);
+       if (mkdir(dir, 0755) == -1)
+           DEBUGF(INDI::Logger::DBG_ERROR, "Error creating directory %s (%s)", dir, strerror(errno));
+    }
+
     dpdf = opendir(dir);
     if (dpdf != NULL)
     {
@@ -2091,3 +2300,15 @@ void INDI::CCD::GuideComplete(INDI_EQ_AXIS axis)
 {
     INDI::GuiderInterface::GuideComplete(axis);
 }
+
+bool INDI::CCD::StartStreaming()
+{
+    DEBUG(INDI::Logger::DBG_ERROR, "Streaming is not supported.");
+    return false;
+}
+
+bool INDI::CCD::StopStreaming()
+{
+    DEBUG(INDI::Logger::DBG_ERROR, "Streaming is not supported.");
+    return false;
+}
