@@ -39,7 +39,7 @@ bool INDI::Focuser::initProperties()
 
     /* Port */
     IUFillText(&PortT[0], "PORT", "Port", "/dev/ttyUSB0");
-    IUFillTextVector(&PortTP, PortT, 1, getDeviceName(), "DEVICE_PORT", "Ports", MAIN_CONTROL_TAB, IP_RW, 0, IPS_IDLE);
+    IUFillTextVector(&PortTP, PortT, 1, getDeviceName(), "DEVICE_PORT", "Ports", OPTIONS_TAB, IP_RW, 0, IPS_IDLE);
 
     // Presets
     IUFillNumber(&PresetN[0], "Preset 1", "", "%6.2f", 0, 60000, 1000, 0);
@@ -61,7 +61,7 @@ bool INDI::Focuser::initProperties()
 
     controller->initProperties();
 
-    setInterfaceDescriptor(FOCUSER_INTERFACE);
+    setDriverInterface(FOCUSER_INTERFACE);
 
     return true;
 }
@@ -72,6 +72,7 @@ void INDI::Focuser::ISGetProperties (const char *dev)
     DefaultDevice::ISGetProperties(dev);
 
     defineText(&PortTP);
+    loadConfig(true, "DEVICE_PORT");
 
     controller->ISGetProperties(dev);
     return;
@@ -84,18 +85,18 @@ bool INDI::Focuser::updateProperties()
         //  Now we add our focusser specific stuff
         defineSwitch(&FocusMotionSP);
 
-        if (capability.variableSpeed)
+        if (HasVariableSpeed())
         {
             defineNumber(&FocusSpeedNP);
             defineNumber(&FocusTimerNP);
         }
-        if (capability.canRelMove)
+        if (CanRelMove())
             defineNumber(&FocusRelPosNP);
-        if (capability.canAbsMove)
+        if (CanAbsMove())
             defineNumber(&FocusAbsPosNP);
-        if (capability.canAbort)
+        if (CanAbort())
             defineSwitch(&AbortSP);
-        if (capability.canAbsMove)
+        if (CanAbsMove())
         {
             defineNumber(&PresetNP);
             defineSwitch(&PresetGotoSP);
@@ -103,18 +104,18 @@ bool INDI::Focuser::updateProperties()
     } else
     {
         deleteProperty(FocusMotionSP.name);
-        if (capability.variableSpeed)
+        if (HasVariableSpeed())
         {
             deleteProperty(FocusSpeedNP.name);
             deleteProperty(FocusTimerNP.name);
         }
-        if (capability.canRelMove)
+        if (CanRelMove())
             deleteProperty(FocusRelPosNP.name);
-        if (capability.canAbsMove)
+        if (CanAbsMove())
             deleteProperty(FocusAbsPosNP.name);
-        if (capability.canAbort)
+        if (CanAbort())
             deleteProperty(AbortSP.name);
-        if (capability.canAbsMove)
+        if (CanAbsMove())
         {
             deleteProperty(PresetNP.name);
             deleteProperty(PresetGotoSP.name);
@@ -256,12 +257,12 @@ void INDI::Focuser::processButton(const char * button_n, ISState state)
         {
             AbortSP.s = IPS_OK;
             DEBUG(INDI::Logger::DBG_SESSION, "Focuser aborted.");
-            if (capability.canAbsMove && FocusAbsPosNP.s != IPS_IDLE)
+            if (CanAbsMove() && FocusAbsPosNP.s != IPS_IDLE)
             {
                 FocusAbsPosNP.s = IPS_IDLE;
                 IDSetNumber(&FocusAbsPosNP, NULL);
             }
-            if (capability.canRelMove && FocusRelPosNP.s != IPS_IDLE)
+            if (CanRelMove() && FocusRelPosNP.s != IPS_IDLE)
             {
                 FocusRelPosNP.s = IPS_IDLE;
                 IDSetNumber(&FocusRelPosNP, NULL);
@@ -285,13 +286,13 @@ void INDI::Focuser::processButton(const char * button_n, ISState state)
             IDSetSwitch(&FocusMotionSP, NULL);
         }
 
-        if (capability.variableSpeed)
+        if (HasVariableSpeed())
         {
            rc = MoveFocuser(FOCUS_INWARD, FocusSpeedN[0].value, FocusTimerN[0].value);
            FocusTimerNP.s = rc;
            IDSetNumber(&FocusTimerNP,NULL);
         }
-        else if (capability.canRelMove)
+        else if (CanRelMove())
         {
             rc=MoveRelFocuser(FOCUS_INWARD, FocusRelPosN[0].value);
             if (rc == IPS_OK)
@@ -316,13 +317,13 @@ void INDI::Focuser::processButton(const char * button_n, ISState state)
             IDSetSwitch(&FocusMotionSP, NULL);
         }
 
-        if (capability.variableSpeed)
+        if (HasVariableSpeed())
         {
            rc = MoveFocuser(FOCUS_OUTWARD, FocusSpeedN[0].value, FocusTimerN[0].value);
            FocusTimerNP.s = rc;
            IDSetNumber(&FocusTimerNP,NULL);
         }
-        else if (capability.canRelMove)
+        else if (CanRelMove())
         {
             rc=MoveRelFocuser(FOCUS_OUTWARD, FocusRelPosN[0].value);
             if (rc == IPS_OK)
