@@ -25,12 +25,13 @@
 
 INDI::Telescope::Telescope()
 {
-    capability.canPark = capability.canSync = capability.canAbort = false;
-    capability.nSlewRate = 0;
+    capability=0;
     last_we_motion = last_ns_motion = -1;
     parkDataType = PARK_NONE;
     Parkdatafile= "~/.indi/ParkData.xml";
     IsParked=false;
+
+    nSlewRate=0;
     SlewRateS = NULL;
 
     controller = new INDI::Controller(this);
@@ -57,6 +58,11 @@ bool INDI::Telescope::initProperties()
     IUFillNumberVector(&EqNP,EqN,2,getDeviceName(),"EQUATORIAL_EOD_COORD","Eq. Coordinates",MAIN_CONTROL_TAB,IP_RW,60,IPS_IDLE);
     lastEqState = IPS_IDLE;
 
+    IUFillNumber(&TargetN[AXIS_RA],"RA","RA (hh:mm:ss)","%010.6m",0,24,0,0);
+    IUFillNumber(&TargetN[AXIS_DE],"DEC","DEC (dd:mm:ss)","%010.6m",-90,90,0,0);
+    IUFillNumberVector(&TargetNP,TargetN,2,getDeviceName(),"TARGET_EOD_COORD","Slew Target",MOTION_TAB,IP_RO,60,IPS_IDLE);
+
+
     IUFillSwitch(&ParkOptionS[0],"PARK_CURRENT","Current",ISS_OFF);
     IUFillSwitch(&ParkOptionS[1],"PARK_DEFAULT","Default",ISS_OFF);
     IUFillSwitch(&ParkOptionS[2],"PARK_WRITE_DATA","Write Data",ISS_OFF);
@@ -75,13 +81,13 @@ bool INDI::Telescope::initProperties()
     IUFillSwitch(&CoordS[1],"SLEW","Slew",ISS_OFF);
     IUFillSwitch(&CoordS[2],"SYNC","Sync",ISS_OFF);
 
-    if (capability.canSync)
+    if (CanSync())
         IUFillSwitchVector(&CoordSP,CoordS,3,getDeviceName(),"ON_COORD_SET","On Set",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
     else
         IUFillSwitchVector(&CoordSP,CoordS,2,getDeviceName(),"ON_COORD_SET","On Set",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
-    if (capability.nSlewRate >= 4)
-        IUFillSwitchVector(&SlewRateSP, SlewRateS, capability.nSlewRate, getDeviceName(), "TELESCOPE_SLEW_RATE", "Slew Rate", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+    if (nSlewRate >= 4)
+        IUFillSwitchVector(&SlewRateSP, SlewRateS, nSlewRate, getDeviceName(), "TELESCOPE_SLEW_RATE", "Slew Rate", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
 
     IUFillSwitch(&ParkS[0],"PARK","Park",ISS_OFF);
     IUFillSwitch(&ParkS[1],"UNPARK","UnPark",ISS_OFF);
@@ -109,18 +115,18 @@ bool INDI::Telescope::initProperties()
     IUFillSwitch(&MovementWES[DIRECTION_EAST], "MOTION_EAST", "East", ISS_OFF);
     IUFillSwitchVector(&MovementWESP, MovementWES, 2, getDeviceName(),"TELESCOPE_MOTION_WE", "Motion W/E", MOTION_TAB, IP_RW, ISR_ATMOST1, 60, IPS_IDLE);
 
-    IUFillNumber(&ScopeParametersN[0],"TELESCOPE_APERTURE","Aperture (mm)","%g",50,4000,0,0.0);
+    IUFillNumber(&ScopeParametersN[0],"TELESCOPE_APERTURE","Aperture (mm)","%g",10,5000,0,0.0);
     IUFillNumber(&ScopeParametersN[1],"TELESCOPE_FOCAL_LENGTH","Focal Length (mm)","%g",100,10000,0,0.0 );
-    IUFillNumber(&ScopeParametersN[2],"GUIDER_APERTURE","Guider Aperture (mm)","%g",50,4000,0,0.0);
+    IUFillNumber(&ScopeParametersN[2],"GUIDER_APERTURE","Guider Aperture (mm)","%g",10,5000,0,0.0);
     IUFillNumber(&ScopeParametersN[3],"GUIDER_FOCAL_LENGTH","Guider Focal Length (mm)","%g",100,10000,0,0.0 );
     IUFillNumberVector(&ScopeParametersNP,ScopeParametersN,4,getDeviceName(),"TELESCOPE_INFO","Scope Properties",OPTIONS_TAB,IP_RW,60,IPS_OK);
 
     controller->mapController("MOTIONDIR", "N/S/W/E Control", INDI::Controller::CONTROLLER_JOYSTICK, "JOYSTICK_1");
-    if (capability.nSlewRate >= 4)
+    if (nSlewRate >= 4)
         controller->mapController("SLEWPRESET", "Slew Rate", INDI::Controller::CONTROLLER_JOYSTICK, "JOYSTICK_2");
-    if (capability.canAbort)
+    if (CanAbort())
         controller->mapController("ABORTBUTTON", "Abort", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_1");
-    if (capability.canPark)
+    if (CanPark())
     {
         controller->mapController("PARKBUTTON", "Park", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_2");
         controller->mapController("UNPARKBUTTON", "UnPark", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_3");
@@ -129,7 +135,7 @@ bool INDI::Telescope::initProperties()
 
     TrackState=SCOPE_IDLE;
 
-    setInterfaceDescriptor(TELESCOPE_INTERFACE);
+    setDriverInterface(TELESCOPE_INTERFACE);
 
     IDSnoopDevice(ActiveDeviceT[0].text,"GEOGRAPHIC_COORD");
     IDSnoopDevice(ActiveDeviceT[0].text,"TIME_UTC");
@@ -143,22 +149,29 @@ void INDI::Telescope::ISGetProperties (const char *dev)
     DefaultDevice::ISGetProperties(dev);
 
     defineText(&PortTP);
+    loadConfig(true, "DEVICE_PORT");
     defineSwitch(&BaudRateSP);
+    loadConfig(true, "TELESCOPE_BAUD_RATE");
+    if (HasTime() && HasLocation())
+    {
+        defineText(&ActiveDeviceTP);
+        loadConfig(true, "ACTIVE_DEVICES");
+    }
 
     if(isConnected())
     {
         //  Now we add our telescope specific stuff
         defineSwitch(&CoordSP);
         defineNumber(&EqNP);
-        if (capability.canAbort)
+        if (CanAbort())
             defineSwitch(&AbortSP);
 
-        if (capability.hasTime)
+        if (HasTime())
             defineText(&TimeTP);
-        if (capability.hasLocation)
+        if (HasLocation())
             defineNumber(&LocationNP);
 
-        if (capability.canPark)
+        if (CanPark())
         {
             defineSwitch(&ParkSP);
             if (parkDataType != PARK_NONE)
@@ -170,13 +183,11 @@ void INDI::Telescope::ISGetProperties (const char *dev)
         defineSwitch(&MovementNSSP);
         defineSwitch(&MovementWESP);
 
-        if (capability.nSlewRate >= 4)
+        if (nSlewRate >= 4)
             defineSwitch(&SlewRateSP);
 
-        defineNumber(&ScopeParametersNP);
-
-        if (capability.hasTime && capability.hasLocation)
-            defineText(&ActiveDeviceTP);
+        defineNumber(&ScopeParametersNP);        
+        defineNumber(&TargetNP);        
 
     }
 
@@ -192,18 +203,18 @@ bool INDI::Telescope::updateProperties()
         //  Now we add our telescope specific stuff
         defineSwitch(&CoordSP);
         defineNumber(&EqNP);
-        if (capability.canAbort)
+        if (CanAbort())
             defineSwitch(&AbortSP);
         defineSwitch(&MovementNSSP);
         defineSwitch(&MovementWESP);
-        if (capability.nSlewRate >= 4)
+        if (nSlewRate >= 4)
             defineSwitch(&SlewRateSP);
 
-        if (capability.hasTime)
+        if (HasTime())
             defineText(&TimeTP);
-        if (capability.hasLocation)
+        if (HasLocation())
             defineNumber(&LocationNP);
-        if (capability.canPark)
+        if (CanPark())
         {
             defineSwitch(&ParkSP);
             if (parkDataType != PARK_NONE)
@@ -213,28 +224,26 @@ bool INDI::Telescope::updateProperties()
             }
         }
         defineNumber(&ScopeParametersNP);
-
-        if (capability.hasTime && capability.hasLocation)
-            defineText(&ActiveDeviceTP);
+        defineNumber(&TargetNP);        
 
     }
     else
     {
         deleteProperty(CoordSP.name);
         deleteProperty(EqNP.name);
-        if (capability.canAbort)
+        if (CanAbort())
             deleteProperty(AbortSP.name);
         deleteProperty(MovementNSSP.name);
         deleteProperty(MovementWESP.name);
-        if (capability.nSlewRate >= 4)
+        if (nSlewRate >= 4)
             deleteProperty(SlewRateSP.name);
 
-        if (capability.hasTime)
+        if (HasTime())
             deleteProperty(TimeTP.name);
-        if (capability.hasLocation)
+        if (HasLocation())
             deleteProperty(LocationNP.name);
 
-        if (capability.canPark)
+        if (CanPark())
         {
             deleteProperty(ParkSP.name);
             if (parkDataType != PARK_NONE)
@@ -244,9 +253,6 @@ bool INDI::Telescope::updateProperties()
             }
         }
         deleteProperty(ScopeParametersNP.name);
-
-        if (capability.hasTime && capability.hasLocation)
-            deleteProperty(ActiveDeviceTP.name);
     }
 
     controller->updateProperties();
@@ -263,7 +269,7 @@ bool INDI::Telescope::ISSnoopDevice(XMLEle *root)
 
     if (isConnected())
     {
-        if (capability.hasLocation && !strcmp(propName, "GEOGRAPHIC_COORD"))
+        if (HasLocation() && !strcmp(propName, "GEOGRAPHIC_COORD"))
         {
             // Only accept IPS_OK state
             if (strcmp(findXMLAttValu(root, "state"), "Ok"))
@@ -286,7 +292,7 @@ bool INDI::Telescope::ISSnoopDevice(XMLEle *root)
 
             return processLocationInfo(latitude, longitude, elevation);
         }
-        else if (capability.hasTime && !strcmp(propName, "TIME_UTC"))
+        else if (HasTime() && !strcmp(propName, "TIME_UTC"))
         {
             // Only accept IPS_OK state
             if (strcmp(findXMLAttValu(root, "state"), "Ok"))
@@ -316,7 +322,7 @@ bool INDI::Telescope::saveConfigItems(FILE *fp)
     IUSaveConfigText(fp, &ActiveDeviceTP);
     IUSaveConfigText(fp, &PortTP);
     IUSaveConfigSwitch(fp, &BaudRateSP);
-    if (capability.hasLocation)
+    if (HasLocation())
         IUSaveConfigNumber(fp,&LocationNP);
     IUSaveConfigNumber(fp, &ScopeParametersNP);
 
@@ -464,7 +470,7 @@ bool INDI::Telescope::ISNewNumber (const char *dev, const char *name, double val
             if ((ra>=0)&&(ra<=24)&&(dec>=-90)&&(dec<=90))
             {
                 // Check if it is already parked.
-                if (capability.canPark)
+                if (CanPark())
                 {
                     if (isParked())
                     {
@@ -476,7 +482,7 @@ bool INDI::Telescope::ISNewNumber (const char *dev, const char *name, double val
                 }
 
                 // Check if it can sync
-                if (capability.canSync)
+                if (CanSync())
                 {
                     ISwitch *sw;
                     sw=IUFindSwitch(&CoordSP,"SYNC");
@@ -494,10 +500,16 @@ bool INDI::Telescope::ISNewNumber (const char *dev, const char *name, double val
 
                 // Issue GOTO
                 rc=Goto(ra,dec);
-                if (rc)
+                if (rc) {
                     EqNP .s = lastEqState = IPS_BUSY;
-                else
+		    //  Now fill in target co-ords, so domes can start turning
+		    TargetN[AXIS_RA].value=ra;
+		    TargetN[AXIS_DE].value=dec;
+                    IDSetNumber(&TargetNP, NULL);
+
+		} else {
                     EqNP.s = lastEqState = IPS_ALERT;
+		}
                 IDSetNumber(&EqNP, NULL);
 
             }
@@ -592,7 +604,7 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
             if (TrackState == SCOPE_PARKING)
             {
                 IUResetSwitch(&ParkSP);
-                ParkSP.s == IPS_IDLE;
+                ParkSP.s == IPS_ALERT;
                 Abort();
                 DEBUG(INDI::Logger::DBG_SESSION, "Parking/Unparking aborted.");
                 IDSetSwitch(&ParkSP, NULL);
@@ -654,7 +666,7 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
         if(!strcmp(name,MovementNSSP.name))
         {            
             // Check if it is already parked.
-            if (capability.canPark)
+            if (CanPark())
             {
                 if (isParked())
                 {
@@ -708,7 +720,7 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
         if(!strcmp(name,MovementWESP.name))
         {
             // Check if it is already parked.
-            if (capability.canPark)
+            if (CanPark())
             {
                 if (isParked())
                 {
@@ -766,9 +778,11 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
             if (Abort())
             {
                 AbortSP.s = IPS_OK;
+
                 if (ParkSP.s == IPS_BUSY)
                 {
-                    ParkSP.s = IPS_IDLE;
+                    IUResetSwitch(&ParkSP);
+                    ParkSP.s = IPS_ALERT;
                     IDSetSwitch(&ParkSP, NULL);
                 }
                 if (EqNP.s == IPS_BUSY)
@@ -782,7 +796,6 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
                     MovementWESP.s = IPS_IDLE;
                     IDSetSwitch(&MovementWESP, NULL);
                 }
-
                 if (MovementNSSP.s == IPS_BUSY)
                 {
                     IUResetSwitch(&MovementNSSP);
@@ -790,12 +803,6 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
                     IDSetSwitch(&MovementNSSP, NULL);
                 }
 
-                if (EqNP.s == IPS_BUSY)
-                {
-                    EqNP.s = lastEqState = IPS_IDLE;
-                    IDSetNumber(&EqNP, NULL);
-                }
-
                 last_ns_motion=last_we_motion=-1;
                 if (TrackState != SCOPE_PARKED)
                     TrackState = SCOPE_IDLE;
@@ -879,7 +886,7 @@ bool INDI::Telescope::Connect()
 }
 
 
-bool INDI::Telescope::Connect(const char *port, uint16_t baud)
+bool INDI::Telescope::Connect(const char *port, uint32_t baud)
 {
     //  We want to connect to a port
     //  For now, we will assume it's a serial port
@@ -1040,26 +1047,22 @@ bool INDI::Telescope::updateLocation(double latitude, double longitude, double e
     return true;
 }
 
-void INDI::Telescope::SetTelescopeCapability(TelescopeCapability *cap)
+void INDI::Telescope::SetTelescopeCapability(uint32_t cap, uint8_t slewRateCount)
 {
-    capability.canPark      = cap->canPark;
-    capability.canSync      = cap->canSync;
-    capability.canAbort     = cap->canAbort;
-    capability.hasTime      = cap->hasTime;
-    capability.hasLocation  = cap->hasLocation;
-    capability.nSlewRate    = cap->nSlewRate;
+    capability = cap;
+    nSlewRate = slewRateCount;
 
-    if (capability.canSync)
+    if (CanSync())
         IUFillSwitchVector(&CoordSP,CoordS,3,getDeviceName(),"ON_COORD_SET","On Set",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
     else
         IUFillSwitchVector(&CoordSP,CoordS,2,getDeviceName(),"ON_COORD_SET","On Set",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
-    if (capability.nSlewRate >= 4)
+    if (nSlewRate >= 4)
     {
         free(SlewRateS);
-        SlewRateS = (ISwitch *) malloc(sizeof(ISwitch) * capability.nSlewRate);
-        int step = capability.nSlewRate / 4;
-        for (int i=0; i < capability.nSlewRate; i++)
+        SlewRateS = (ISwitch *) malloc(sizeof(ISwitch) * nSlewRate);
+        int step = nSlewRate / 4;
+        for (int i=0; i < nSlewRate; i++)
         {
             char name[4];
             snprintf(name, 4, "%dx", i+1);
@@ -1069,12 +1072,12 @@ void INDI::Telescope::SetTelescopeCapability(TelescopeCapability *cap)
         strncpy( (SlewRateS+(step*0))->name, "SLEW_GUIDE", MAXINDINAME);
         strncpy( (SlewRateS+(step*1))->name, "SLEW_CENTERING", MAXINDINAME);
         strncpy( (SlewRateS+(step*2))->name, "SLEW_FIND", MAXINDINAME);
-        strncpy( (SlewRateS+(capability.nSlewRate-1))->name, "SLEW_MAX", MAXINDINAME);
+        strncpy( (SlewRateS+(nSlewRate-1))->name, "SLEW_MAX", MAXINDINAME);
 
         // By Default we set current Slew Rate to 0.5 of max
-        (SlewRateS+(capability.nSlewRate/2))->s = ISS_ON;
+        (SlewRateS+(nSlewRate/2))->s = ISS_ON;
 
-        IUFillSwitchVector(&SlewRateSP, SlewRateS, capability.nSlewRate, getDeviceName(), "TELESCOPE_SLEW_RATE", "Slew Rate", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+        IUFillSwitchVector(&SlewRateSP, SlewRateS, nSlewRate, getDeviceName(), "TELESCOPE_SLEW_RATE", "Slew Rate", MOTION_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
     }
 }
 
@@ -1118,16 +1121,16 @@ void INDI::Telescope::SetParked(bool isparked)
 {
   IsParked=isparked;
   IUResetSwitch(&ParkSP);
+
+  ParkSP.s = IPS_OK;
   if (IsParked)
-  {
-      ParkSP.s = IPS_OK;
+  {      
       ParkS[0].s = ISS_ON;
       TrackState = SCOPE_PARKED;
       DEBUG(INDI::Logger::DBG_SESSION, "Mount is parked.");
   }
   else
   {
-      ParkSP.s=IPS_IDLE;
       ParkS[1].s = ISS_ON;
       TrackState = SCOPE_IDLE;
       DEBUG(INDI::Logger::DBG_SESSION, "Mount is unparked.");
@@ -1245,8 +1248,17 @@ char *INDI::Telescope::LoadParkData()
   if (!strcmp(pcdataXMLEle(ParkstatusXml), "true"))
       IsParked=true; 
 
-  sscanf(pcdataXMLEle(ParkpositionAxis1Xml), "%lf", &Axis1ParkPosition);
-  sscanf(pcdataXMLEle(ParkpositionAxis2Xml), "%lf", &Axis2ParkPosition);
+  int rc=0;
+  rc = sscanf(pcdataXMLEle(ParkpositionAxis1Xml), "%lf", &Axis1ParkPosition);
+  if (rc != 1)
+  {
+      return (char *)("Unable to parse Park Position Axis 1.");
+  }
+  rc = sscanf(pcdataXMLEle(ParkpositionAxis2Xml), "%lf", &Axis2ParkPosition);
+  if (rc != 1)
+  {
+      return (char *)("Unable to parse Park Position Axis 2.");
+  }
 
   return NULL;
 }
