@@ -23,6 +23,8 @@
 
 */
 
+#define _GNU_SOURCE 1
+
 #include <stdlib.h>
 #include <math.h>
 #include <stdio.h>
@@ -174,14 +176,8 @@ double *dp)		/* cracked value, if return 0 */
 	neg = strchr(str, '-');
 	if (neg)
 	    *neg = ' ';
-    // JM 2015-09-04 Search for decimal point, and if found, process it
-    if (strchr(str, '.'))
-    {
-        r = sscanf (str, "%lf%*[^0-9]%lf", &a, &b);
-        c=0;
-    }
-    else
-        r = sscanf (str, "%lf%*[^0-9]%lf%*[^0-9]%lf", &a, &b, &c);
+
+    r = sscanf (str, "%lf%*[^0-9]%lf%*[^0-9]%lf", &a, &b, &c);
 
     setlocale(LC_NUMERIC,"");
 
@@ -1283,9 +1279,9 @@ double get_local_hour_angle(double sideral_time, double ra)
     double HA = sideral_time - ra;
 
          if (HA > 12)
-             HA -= 12;
+             HA -= 24;
          else if (HA < -12)
-             HA += 12;
+             HA += 24;
 
     return HA;
 }
